@@ -22,7 +22,7 @@
  *
  * the adt theories
  *
- * $Id: adt_theory.ml,v 1.14 2002/05/22 13:42:37 tews Exp $
+ * $Id: adt_theory.ml,v 1.15 2002/07/18 13:43:20 tews Exp $
  *
  *)
 
@@ -41,10 +41,64 @@ open Lifting
 open Theory_class
 
 
-(*********************************************************************
+(***********************************************************************
+ ***********************************************************************
+ *
+ * Isar start / close class
+ * 
+ *
+ *)
+
+class ccsl_isar_start_adt adt =
+  let pre_imports = 
+    List.fold_right
+      (fun (v,c,args) accu -> match c#get_kind with
+	 | Spec_adt 
+	 | Spec_class ->
+	     (isar_theory_name c) :: accu
+	 | Spec_sig -> 
+	     if c#has_own_output
+	     then			(* does have an own theory *)
+	       (isar_theory_name c) :: accu
+	     else 			(* no own theory for c *)
+	       (List.map fst c#get_iface_imports) @ accu
+	 | Spec_Spec -> assert(false)
+      )
+      adt#get_components []
+  in 
+  let imports =
+    match remove_duplicates (=) pre_imports with
+      | [] -> [isabelle_top_theory]
+      | l -> l
+  in
+    [ccsl_iface_type, ccsl_member_type] 
+    ccsl_pre_isabelle_delimiter_theory_class
+      adt
+      eq_ccsl_types
+      IsabelleStartFile
+      (ccsl_adt_file_name adt)
+      imports
+
+
+class ccsl_isar_close_adt adt =
+  [ccsl_iface_type, ccsl_member_type] 
+  ccsl_pre_isabelle_delimiter_theory_class
+    adt
+    eq_ccsl_types
+    IsabelleCloseFile
+    (ccsl_adt_file_name adt)
+    []
+
+    
+
+(***********************************************************************
+ ***********************************************************************
+ *
  * Adt declaration for PVS, this is the easy case, simply declare the
  * constructors and accessors
+ *
  *)
+
   
 class ['class_type, 'member_type] ccsl_pvs_pre_adt_theory 
   (adt : 'class_type) 
@@ -71,7 +125,9 @@ class ['class_type, 'member_type] ccsl_pvs_pre_adt_theory
 
     initializer top_theory#override_file_name (ccsl_adt_file_name adt)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method private component_imports =
       let subst_carrier = 
@@ -184,7 +240,9 @@ class ['class_type, 'member_type] ccsl_isa_pre_adt_theory
 
     initializer top_theory#override_file_name (ccsl_adt_file_name adt)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method private component_imports =
       let imp_list = 
@@ -285,15 +343,10 @@ class ['class_type, 'member_type] ccsl_isa_pre_adtutil_theory
 
     initializer top_theory#override_file_name (ccsl_adt_file_name adt)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
-    method private import =
-      	Import(
-	  [ if adt#has_feature BuildinFeature 
-	    then (isabelle_top_theory, [])
-	    else (ccsl_adt_theory_name adt,[])
-	  ]
-      	)
 
 					(* define accessors as primrec's *)
     method private accessors constr = 
@@ -809,8 +862,6 @@ class ['class_type, 'member_type] ccsl_isa_pre_adtutil_theory
 
 
     method make_body =
-      [self#import
-      ]
 (* PRIMREC 
  * 	 @
  * 	 List.flatten(
@@ -819,7 +870,6 @@ class ['class_type, 'member_type] ccsl_isa_pre_adtutil_theory
  * 	 @
  * 	 List.map self#recognizers adt#get_adt_constructors
  *)
-      @
       [self#reduce_rec]
       @
       List.flatten(
@@ -865,7 +915,9 @@ class ['class_type, 'member_type] ccsl_pre_adt_every_theory
 
     initializer top_theory#override_file_name (ccsl_adt_file_name adt)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method private import =
       Import(
@@ -1093,7 +1145,9 @@ class ['class_type, 'member_type] ccsl_pre_adt_rellift_theory
 
     initializer top_theory#override_file_name (ccsl_adt_file_name adt)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method private adt_import = 
       let (param_left,param_right) = self#double_parameters in
@@ -1262,7 +1316,9 @@ class ['class_type, 'member_type] ccsl_pre_adt_map_theory
 
     initializer top_theory#override_file_name (ccsl_adt_file_name adt)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method private adt_import = 
       let (param_from,param_to) = self#double_parameters in
