@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 15:38:03 tews@ithif51>
+ * Time-stamp: <Thursday 4 July 02 18:46:40 tews@ithif51>
  *
  * Bisimilarity theories
  *
- * $Id: bisim_theory.ml,v 1.12 2002/05/22 13:42:38 tews Exp $
+ * $Id: bisim_theory.ml,v 1.13 2002/07/18 13:43:20 tews Exp $
  *
  *)
 
@@ -336,9 +336,9 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
 	     [decl1_list; decl2_list; [ Undeclared(r, type_of_rel) ]],
 	     Bool,
 	     Application(
-	       Application(
+	       SmartApplication(
 		 Term(name_of_private_bibisimulation cl, Always, []),
-		 Tuple([c1_tuple; c2_tuple])
+		 [c1_tuple; c2_tuple]
 	       ),
 	       Term(r,Always,[])
 	     ))
@@ -412,7 +412,9 @@ class ['class_type, 'member_type] ccsl_pre_bibisim_theory
 	  []
       )
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 end
 
 class ccsl_bibisim_theory cl = 
@@ -455,7 +457,9 @@ class virtual ['class_type, 'member_type]
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 
     method private do_bisim_method m =
@@ -694,7 +698,9 @@ class ['class_type, 'member_type] ccsl_pre_bisim_eq_theory
 	  []
       )
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 end
 
 class ccsl_bisim_eq_theory cl = 
@@ -962,7 +968,9 @@ class ['class_type, 'member_type] ccsl_pre_req_bisim_theory
       ] @
       (List.map self#do_request_decl cl#get_rel_lifting_requests)
       
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 			  
 end (* ccsl_pre_req_bisim_theory *)
 
