@@ -18,11 +18,11 @@
  *
  * Created 24.8.01 by Hendrik
  *
- * Time-stamp: <Sunday 19 May 02 16:22:39 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Tuesday 16 July 02 10:23:50 tews@ithif51>
  *
  * pretty printer for CCSL
  *
- * $Id: ccsl_pretty.ml,v 1.13 2002/05/22 13:42:38 tews Exp $
+ * $Id: ccsl_pretty.ml,v 1.14 2002/07/18 13:43:20 tews Exp $
  *
  *)
 
@@ -138,9 +138,17 @@ let rec ccsl_pp_type
   	end
     | FreeTypeVariable tv -> 
 	print_string (Type_variable.string_of_tv tv)
+
+					(* occurs in special class members *)
+    | SmartFunction(arg_t_list, res_t) ->
+	(match arg_t_list with
+	   | [] -> assert false
+	   | [t] -> ccsl_pp_type (Function(t, res_t))
+	   | _ -> ccsl_pp_type (Function(Product(arg_t_list), res_t))
+	)
 					(* not allowed *)
+
     | TypeConstant _
-    | SmartFunction _
     | Record _ 
     | IFace _
     | Array _ 
@@ -503,8 +511,6 @@ and ccsl_pp_expression (* : top_expressions -> unit *)
     | Every _
     | RelEvery _
     | Map _
-    | Comment_str _
-    | Comment_expr _
     | Comprehension _ ->
       	assert(false)
 
