@@ -18,11 +18,11 @@
  *
  * Created 22.4.99 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 13:02:59 tews@ithif51>
+ * Time-stamp: <Thursday 11 July 02 18:09:24 tews@ithif51>
  *
  * type hierarchy for CCSL
  *
- * $Id: classtypes.ml,v 1.16 2002/05/22 13:42:38 tews Exp $
+ * $Id: classtypes.ml,v 1.17 2002/07/18 13:43:21 tews Exp $
  *
  *)
 
@@ -535,7 +535,9 @@ class type virtual
 
     method assert_coalgebra1_type : ('class_type, 'member_type) top_pre_types
 
-    method assert_coalgebra2_type : ('class_type, 'member_type) top_pre_types
+(* ISAR
+ *     method assert_coalgebra2_type : ('class_type, 'member_type) top_pre_types
+ *)
 
       (* a complete variable declaration for the coalgebra *)
     method coalgebra_decl :
@@ -550,11 +552,13 @@ class type virtual
     method assert_coalgebra_decl :
       ('class_type, 'member_type) top_pre_theory_declaration
 
-    method assert_coalgebra1_decl :
-      ('class_type, 'member_type) top_pre_theory_declaration
-
-    method assert_coalgebra2_decl :
-      ('class_type, 'member_type) top_pre_theory_declaration
+(* ISAR
+ *     method assert_coalgebra1_decl :
+ * 	 ('class_type, 'member_type) top_pre_theory_declaration
+ * 
+ *     method assert_coalgebra2_decl :
+ * 	 ('class_type, 'member_type) top_pre_theory_declaration
+ *)
 
       (* coalgebra term is in ccsl_pre_theory_body_type *)
 
@@ -633,8 +637,10 @@ class type ['class_type, 'member_type] ccsl_pre_class_theory_type =
     method make_body :
       ('class_type, 'member_type) top_pre_theory_declaration list
 
-    method get_proofs :
-      ('class_type, 'member_type) top_pre_proof_file_entry list
+(* ISAR
+ *     method get_proofs :
+ * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
+ *)
 
   end (* ccsl_pre_class_theory_type *)
 
@@ -686,8 +692,10 @@ class type ['class_type, 'member_type] ccsl_pre_adt_theory_type =
     method make_body :
       ('class_type, 'member_type) top_pre_theory_declaration list
 
-    method get_proofs :
-      ('class_type, 'member_type) top_pre_proof_file_entry list
+(* ISAR
+ *     method get_proofs :
+ * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
+ *)
 
   end (* ccsl_pre_adt_theory_type *)
 
@@ -737,8 +745,10 @@ class type ['class_type, 'member_type] ccsl_pre_sig_theory_type =
     method make_body :
       ('class_type, 'member_type) top_pre_theory_declaration list
 
-    method get_proofs :
-      ('class_type, 'member_type) top_pre_proof_file_entry list
+(* ISAR
+ *     method get_proofs :
+ * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
+ *)
 
   end (* ccsl_pre_sig_theory_type *)
 
