@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 14:18:08 tews@ithif51>
+ * Time-stamp: <Saturday 25 May 02 13:08:00 tews@ithif56.inf.tu-dresden.de>
  *
  * adding components
  *
- * $Id: component_pass.ml,v 1.5 2002/05/22 13:42:39 tews Exp $
+ * $Id: component_pass.ml,v 1.6 2002/05/30 13:10:29 tews Exp $
  *
  *)
 
@@ -168,6 +168,11 @@ let do_typedef si idrec = match idrec.id_origin with
   | CCSL_GroundTypeDecl _ -> ()
   | _ -> assert(false)
 
+let do_si_def si def =
+  let m = def.defined_method 
+  in
+    iter_components_add_component si m#get_full_type
+
 
 
 (***********************************************************************
@@ -194,7 +199,8 @@ let adt_component_pass adt =
 
 
 let sig_component_pass si = 
-  List.iter (do_typedef si) si#get_all_ground_types
+  List.iter (do_typedef si) si#get_all_ground_types;
+  List.iter (do_si_def si) si#get_definitions
 
 
 
