@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Wednesday 15 May 02 17:08:10 tews@ithif51>
  *
  * component pass for CCSL
  *
- * $Id: component_pass.mli,v 1.3 2002/01/23 16:00:14 tews Exp $
+ * $Id: component_pass.mli,v 1.5 2002/05/22 13:42:39 tews Exp $
  *
  *)
 
@@ -40,10 +40,13 @@ val class_component_pass : ccsl_iface_type -> unit
 
 val adt_component_pass : ccsl_iface_type -> unit
 
+val sig_component_pass : ccsl_iface_type -> unit
+
 
 (*** Local Variables: ***)
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
 (*** delete-old-versions: t ***)
+(*** time-stamp-line-limit: 30 ***)
 (*** End: ***)
 
