@@ -18,16 +18,28 @@
  *
  * Created 11.10.01 by Hendrik
  *
- * Time-stamp: <Tuesday 14 May 02 9:55:20 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 15:14:55 tews@ithif51>
  *
- * theories for empty coproduct
+ * addon theories 
  *
- * $Id: emptytype_theory.ml,v 1.4 2002/05/22 13:42:39 tews Exp $
+ * $Id: emptytype_theory.ml,v 1.5 2002/07/18 13:43:21 tews Exp $
+ *
+ *)
+
+(***********************************************************************
+ ***********************************************************************
+ *
+ * In this file there are additional theories for
+ *   - empty type in pvs
+ *   - empty function in pvs
+ *   - sets2pred : 'a set => 'a => bool in isabelle
  *
  *)
 
 
+
 open Name_space
+open Top_names
 open Names
 open Top_variant_types  
 open Pvs_proof_util
@@ -37,6 +49,15 @@ open Classtypes
 open Types_util
 ;;
 
+
+(*******************************************************************
+ *******************************************************************
+ *
+ * Empty class for technical reasons
+ *
+ *)
+
+
 let emptytoken = { token_name = "";
 		   loc = None 
 		 }
@@ -47,6 +68,7 @@ let empty_iface =
 empty_iface#inheritance_done
 ;;
 
+
 (***********************************************************************
  ***********************************************************************
  *
@@ -60,11 +82,11 @@ class ['class_type, 'member_type] ccsl_pre_empty_type_theory
   (eq_types : ('class_type, 'member_type) top_pre_types
      -> ('class_type, 'member_type) top_pre_types -> bool)
 
-  : ['class_type, 'member_type] ccsl_pre_class_theory_type =
+  : ['class_type, 'member_type] ccsl_pre_sig_theory_type =
   object (self : 'self)
 
     inherit 
-      ['class_type, 'member_type] ccsl_pre_class_theory_class cl eq_types
+      ['class_type, 'member_type] ccsl_pre_sig_theory_class cl eq_types
       as top_theory
 
        (* reserve all names, that we want to declare *)
@@ -80,7 +102,9 @@ class ['class_type, 'member_type] ccsl_pre_empty_type_theory
 
     initializer top_theory#override_file_name ccsl_prelude_name
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 
     method private emptytype =
@@ -123,11 +147,11 @@ class ['class_type, 'member_type] ccsl_pre_empty_fun_theory
   (eq_types : ('class_type, 'member_type) top_pre_types
      -> ('class_type, 'member_type) top_pre_types -> bool)
 
-  : ['class_type, 'member_type] ccsl_pre_class_theory_type =
+  : ['class_type, 'member_type] ccsl_pre_sig_theory_type =
   object (self : 'self)
 
     inherit 
-      ['class_type, 'member_type] ccsl_pre_class_theory_class cl eq_types
+      ['class_type, 'member_type] ccsl_pre_sig_theory_class cl eq_types
       as top_theory
 
        (* reserve all names, that we want to declare *)
@@ -154,7 +178,9 @@ class ['class_type, 'member_type] ccsl_pre_empty_fun_theory
 
     initializer top_theory#override_file_name ccsl_prelude_name
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method private fundefn =
       let empty_type = TypeConstant(name_of_empty_type,Always,[]) in
@@ -189,7 +215,7 @@ class ['class_type, 'member_type] ccsl_pre_empty_fun_theory
 	      Term(other_f,Always,[]), 
 		   Term(name_of_empty_fun, Always,[]))))
       in
-	Proved( lem, Anon_proof proof)
+	Proved( lem, PvsProof(Anon_proof proof))
 	  
 
     method make_body = 
@@ -209,6 +235,114 @@ class ccsl_empty_fun_theory =
 
 
 
+(***********************************************************************
+ ***********************************************************************
+ *
+ * Isabelle part
+ *
+ * open close the prelude
+ *)
+
+
+class ccsl_isar_start_prelude =
+  [ccsl_iface_type, ccsl_member_type] 
+  ccsl_pre_isabelle_delimiter_theory_class
+    empty_iface
+    eq_ccsl_types
+    IsabelleStartFile
+    ccsl_prelude_name
+    [isabelle_top_theory]
+
+class ccsl_isar_close_prelude =
+  [ccsl_iface_type, ccsl_member_type] 
+  ccsl_pre_isabelle_delimiter_theory_class
+    empty_iface
+    eq_ccsl_types
+    IsabelleCloseFile
+    ccsl_prelude_name
+    []
+
+    
+  
+(***********************************************************************
+ ***********************************************************************
+ *
+ * Isabelle part
+ *
+ * set2pred
+ *)
+
+class ['class_type, 'member_type] ccsl_pre_isabelle_addon_theory
+  (cl : 'class_type) 
+  (* the equality relation for initializing the name space *)
+  (eq_types : ('class_type, 'member_type) top_pre_types
+     -> ('class_type, 'member_type) top_pre_types -> bool)
+
+  : ['class_type, 'member_type] ccsl_pre_sig_theory_type =
+  object (self : 'self)
+
+    inherit 
+      ['class_type, 'member_type] ccsl_pre_sig_theory_class cl eq_types
+      as top_theory
+
+       (* reserve all names, that we want to declare *)
+    initializer reserve ns 
+      (
+       [ name_of_set2pred;
+       ]
+      )
+
+    val other_type_id = 
+		 { id_token = { token_name = "A";
+				loc = None };
+		   (* the other fields are to ignored *)
+		   id_type = Self;
+		   id_origin = CCSL_TypeParameter;
+		   id_parameters = [];
+		   id_variance = Unset;
+		   id_sequence = -1;
+		 }
+    method get_name = ccsl_isabelle_addon_theory_name
+
+    method get_parameters = [TypeParameter other_type_id]
+
+    initializer top_theory#override_file_name ccsl_prelude_name
+
+    method private quick_and_dirty =
+      [Comment("Enable quick_and_dirty for sorry proofs");
+       IsarML "set quick_and_dirty";
+      ]
+
+    method private pred2set =
+      let subns = sub_space ns in
+      let a = BoundTypeVariable other_type_id in
+      let a_name = other_type_id.id_token.token_name in
+      let styp = TypeConstant("set", Always, [TypeArgument a]) in
+      let s = create_id_with_preference subns "s" "s" in
+      let x = create_id_with_preference subns "a" "a" in
+      Defn(
+	name_of_set2pred,
+	[[Undeclared(s, styp); Undeclared(x,a)]],
+	Bool,
+	Term("( " ^ x ^ " : " ^ s ^ " )", Always, [])
+      )
+
+    method make_body = 
+      self#quick_and_dirty
+      @
+      [      
+	self#pred2set;
+      ]
+
+end (* ccsl_pre_empty_fun_theory *)
+
+class ccsl_isabelle_addon_theory =
+  [ccsl_iface_type, ccsl_member_type] 
+  ccsl_pre_isabelle_addon_theory
+    empty_iface
+    eq_ccsl_types
+
+
 
 
 
