@@ -18,11 +18,11 @@
  *
  * Created 11.10.01 by Hendrik
  *
- * Time-stamp: <Wednesday 15 May 02 18:41:55 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 10:09:03 tews@ithif51>
  *
  * full invariants and bisimulations
  *
- * $Id: full_liftings_theory.ml,v 1.7 2002/05/22 13:42:39 tews Exp $
+ * $Id: full_liftings_theory.ml,v 1.8 2002/07/18 13:43:21 tews Exp $
  *
  *)
 
@@ -75,7 +75,9 @@ class ['class_type, 'member_type] ccsl_pre_full_invariant_theory
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method private do_imports =
       let do_ancestor = function
@@ -84,10 +86,6 @@ class ['class_type, 'member_type] ccsl_pre_full_invariant_theory
 	     self_argument :: args)
 						   (* no other stuff *)
 	| Unresolved_renaming _
-(* NO JAVA ANCESTORS
- * 	   | Resolved_ancestor _ 
- * 	   | Unresolved_ancestor _ 
- *)
 	  -> assert(false)
       in
       let do_component (v,comp, args) accu =
@@ -308,7 +306,41 @@ class ['class_type, 'member_type] ccsl_pre_full_invariant_theory
                        Application(
 			 smart_inner_ex,
                          self_ex)))))))
-                                              
+
+      (* 						 
+       * For PVS simply output
+       *   gfp term
+       * for Isabelle convert between 'a set forth and back:
+       *   set2pred(gfp (% s . Collect(term (set2pred s)))) 
+       * 
+       *)
+    method private gfp_appl ns settype term = 
+      match !Global.output_mode with
+	| Pvs_mode ->
+	    Application(
+	      Term(name_of_gfp,Always,[]),
+	      term)
+	| Isa_mode ->
+	    let sub_ns = sub_space ns in
+	    let styp = TypeConstant("set", Always, [TypeArgument(settype)]) in
+	    let s = create_one_id sub_ns styp 
+	    in
+	      Application(
+		Term(name_of_set2pred,Always,[]),
+		Application(
+		  Term(name_of_gfp,Always,[]),
+		  Abstraction(
+		    [s,styp],
+		    Application(
+		      Term(name_of_pred2set, Always, []),
+		      Application(
+			term,
+			Application(
+			  Term(name_of_set2pred, Always,[]),
+			  Term(s,Always,[])
+		  ))))))
+			      
+		
 
     method private do_every =
       let sub_ns = sub_space ns in
@@ -359,9 +391,8 @@ class ['class_type, 'member_type] ccsl_pre_full_invariant_theory
 	      else 
 		[List.map (fun (id,t) -> Undeclared(id,t)) pred_ids]),
              Function(Self, Bool),
-	     Application(
-	       Term(name_of_gfp,Always,[]),
-	       smart_inner_ex))
+	     self#gfp_appl sub_ns Self smart_inner_ex
+	    )
 
     method make_body = 
       [      
@@ -485,7 +516,9 @@ class ['class_type, 'member_type] ccsl_pre_full_bibisim_theory
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 
 	(* override these two methods to get the coalgebra 
@@ -764,6 +797,39 @@ class ['class_type, 'member_type] ccsl_pre_full_bibisim_theory
                          xy_term)))))))
                                               
 
+      (* 						 
+       * For PVS simply output
+       *   gfp term
+       * for Isabelle convert between 'a set forth and back:
+       *   set2pred(gfp (% s . Collect(term (set2pred s)))) 
+       * 
+       *)
+    method private gfp_appl ns settype term = 
+      match !Global.output_mode with
+	| Pvs_mode ->
+	    Application(
+	      Term(name_of_gfp,Always,[]),
+	      term)
+	| Isa_mode ->
+	    let sub_ns = sub_space ns in
+	    let styp = TypeConstant("set", Always, [TypeArgument(settype)]) in
+	    let s = create_one_id sub_ns styp 
+	    in
+	      Application(
+		Term(name_of_set2pred,Always,[]),
+		Application(
+		  Term(name_of_gfp,Always,[]),
+		  Abstraction(
+		    [s,styp],
+		    Application(
+		      Term(name_of_pred2set, Always, []),
+		      Application(
+			term,
+			Application(
+			  Term(name_of_set2pred, Always,[]),
+			  Term(s,Always,[])
+		  ))))))
+
     method private do_relevery =
       let sub_ns = sub_space ns in
       let r = create_one_id sub_ns self#rel_type in
@@ -816,9 +882,10 @@ class ['class_type, 'member_type] ccsl_pre_full_bibisim_theory
 	      else 
 		[List.map (fun (id,t) -> Undeclared(id,t)) rel_ids]),
              self#rel_type,
-	     Application(
-	       Term(name_of_gfp,Always,[]),
-	       smart_inner_ex))
+	     self#gfp_appl sub_ns 
+	       (Product[self#self1_type; self#self2_type])
+	       smart_inner_ex
+	    )
 
 
 
