@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Wednesday 26 June 02 19:57:22 tews@ithif51>
+ * Time-stamp: <Wednesday 17 July 02 17:28:48 tews@ithif51>
  *
  * the class for ccsl adt's and classes
  *
- * $Id: iface_class.ml,v 1.16 2002/07/03 12:01:14 tews Exp $
+ * $Id: iface_class.ml,v 1.17 2002/07/18 13:43:21 tews Exp $
  *
  *)
 
@@ -536,12 +536,17 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 	(th :> (('member_type, 'theory_body_type, 'super_class)
 	          ccsl_pre_iface_type,
 		  ('super_class, 'member_type) ccsl_pre_member_type)
-	       ccsl_pre_theory_body_type) in
+	       ccsl_pre_theory_body_type) 
+      in
+      let all_theories =
 
       match self#get_kind with 
 					(* generate classes *)
   	| Spec_class ->			
 	    [
+	        (* this is not a theory *)
+	      (sig_typeconvert (new ccsl_isar_start_class self'));
+
 		(* DOC     \name{class}\texttt{Interface} & *)
 		(* DOC2        signature declaration  *)
 	      (class_typeconvert (new ccsl_interface_theory self' ));
@@ -623,7 +628,7 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 		(* DOC     \name{class}\texttt{PublicBisimilarityRewrite} & *)
 		(* DOC2       \raggedright *)
 		(* DOC2       utility lemmas for bisimulations  *)
-		(* DOC2       with respect to the public *)
+		(* DOC2       with respect to the public subsignature *)
 		      (class_typeconvert 
 			 (new ccsl_public_bibisim_rewrite_theory self'))
 		    ]
@@ -795,21 +800,42 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 		(class_typeconvert (new ccsl_coadt_theory self'));
 	      ]
 
+	    ) @ (
+	        (* this is not a theory *)
+	      [
+		sig_typeconvert (new ccsl_isar_close_class self');
+	      ]
+
 	    ) @ (
 
 	      if self#get_theorems <> [] then
 		[
+	          (* this is not a theory *)
+		  sig_typeconvert (new ccsl_isar_start_theorems self');
 
 		(* DOC     \name{class}\texttt{Theorem} & *)
-		(* DOC2        tranlated theorem section *)
-		  class_typeconvert (new ccsl_class_theorem_theory self')
+		(* DOC2        translated theorem section *)
+		  class_typeconvert (new ccsl_class_theorem_theory self');
+
+	          (* this is not a theory *)
+		  sig_typeconvert (new ccsl_isar_close_theorems self');
 		]
 	      else
 		[]
+
 	    )
+
 					(* generate adt's *)
   	| Spec_adt -> 
-	    (match !output_mode with
+	    (
+	      [
+	        (* this is not a theory *)
+		sig_typeconvert (new ccsl_isar_start_adt self');
+	      ]
+
+	    ) @ (
+
+	      match !output_mode with
 	       | Pvs_mode -> 
 		   if self#has_feature BuildinFeature
 		   then []
@@ -850,18 +876,57 @@ class ['member_type, 'theory_body_type, 'super_class] ccsl_pre_iface_class
 		]
 	      else
 		[]
+	    ) @ (
+	        (* this is not a theory *)
+	      [
+		sig_typeconvert (new ccsl_isar_close_adt self');
+	      ]
 	    )
 
 	| Spec_sig ->
 	    (if self#has_own_output
 	     then
-	       List.map sig_typeconvert (ccsl_sig_def_theories self')
+	       (
+		 [
+	           (* this is not a theory *)
+		   sig_typeconvert (new ccsl_isar_start_sig self');
+		 ]
+
+	       ) @ (
+
+		 List.map sig_typeconvert (ccsl_sig_def_theories self')
+
+	       ) @ (
+		 [
+	           (* this is not a theory *)
+		   sig_typeconvert (new ccsl_isar_close_sig self');
+		 ]
+	       )
 	     else
 	       []
 	    )
 	    
   	| Spec_Spec 
 	  -> assert(false)
+
+      in
+	if self#belongs_to_prelude 
+	then
+	  let without_delim =
+	    List.filter 
+	      (fun th -> match th#kind with
+		 | Datatype 
+		 | Theory -> true
+		 | IsabelleStartFile
+		 | IsabelleCloseFile -> false
+	      )
+	      all_theories
+	  in
+	    List.iter (fun th -> th#override_file_name Names.ccsl_prelude_name)
+	      without_delim;
+	    without_delim
+	else
+	  all_theories
 	  
     (*******************************************************************
      *
