@@ -18,11 +18,11 @@
  *
  * Created 17.6.99 by Hendrik
  *
- * Time-stamp: <Monday 24 June 02 10:22:20 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 16:21:33 tews@ithif51>
  *
  * the ccsl interface theory
  *
- * $Id: interface_theory.ml,v 1.12 2002/07/03 12:01:14 tews Exp $
+ * $Id: interface_theory.ml,v 1.13 2002/07/18 13:43:22 tews Exp $
  *
  *)
 
@@ -41,6 +41,64 @@ open Pre_printing
 ;;
 
   
+(***********************************************************************
+ ***********************************************************************
+ *
+ * Isar start / close class
+ * 
+ *
+ *)
+
+class ccsl_isar_start_class cl =
+  let components = 
+    List.fold_right
+      (fun (v,c,args) accu -> match c#get_kind with
+	 | Spec_adt 
+	 | Spec_class ->
+	     (isar_theory_name c) :: accu
+	 | Spec_sig -> 
+	     if c#has_own_output
+	     then			(* does have an own theory *)
+	       (isar_theory_name c) :: accu
+	     else 			(* no own theory for c *)
+	       (List.map fst c#get_iface_imports) @ accu
+	 | Spec_Spec -> assert(false)
+      )
+      cl#get_components []
+  in let supers = List.map isar_theory_name cl#get_resolved_ancestors
+  in
+  let pre_imports = remove_duplicates (=)
+		  ( supers @ components @
+		    (List.map fst cl#get_iface_imports) @
+		    (List.map fst cl#get_assertion_imports)
+		  )
+  in
+  let imports = match pre_imports with
+      (* take prelude here to get the Isbelle addon's *)
+    | [] -> [ccsl_prelude_name]
+    | l -> l
+  in
+    [ccsl_iface_type, ccsl_member_type] 
+    ccsl_pre_isabelle_delimiter_theory_class
+      cl
+      eq_ccsl_types
+      IsabelleStartFile
+      (ccsl_class_file_name cl)
+      imports
+
+
+class ccsl_isar_close_class cl =
+  [ccsl_iface_type, ccsl_member_type] 
+  ccsl_pre_isabelle_delimiter_theory_class
+    cl
+    eq_ccsl_types
+    IsabelleCloseFile
+    (ccsl_class_file_name cl)
+    []
+
+    
+
+
 (***********************************************************************
  ***********************************************************************
  *
@@ -105,7 +163,9 @@ class ['class_type, 'member_type] ccsl_pre_interface_theory
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 
     method private user_imports = cl#get_iface_imports 
@@ -157,6 +217,10 @@ class ['class_type, 'member_type] ccsl_pre_interface_theory
 	   ccsl_basic_theory_name ianc, self_argument:: ianc#get_arguments)
 	cl#get_resolved_ancestors
 
+    method private all_imports =
+      self#component_imports @ self#super_imports @ self#user_imports
+
+
     method private functor_declaration = 
       [Comment("Declare coalgebraic signature for class " ^ cl#get_name);
        Typedecl(self#simple_parameters,
@@ -189,15 +253,11 @@ class ['class_type, 'member_type] ccsl_pre_interface_theory
       let pre_mems = List.map method_name cl#get_sig_actions in
       let mems = create_ids_with_preference sub_ns pre_mems in
       let do_ancestor anc ancmems =
-	let body = match ancmems with
-	  | [(id,_)] -> Term(id,Always,[])
-	  | mlist -> Tuple(List.map (fun (id,_) -> Term(id,Always,[]))
-			     mlist)
-	in
-	  (super_label anc, 
-	   Application(
-	     Term(name_of_struct_of anc, Always,[]),
-	     body))
+	(super_label anc, 
+	 SmartApplication(
+	   Term(name_of_struct_of anc, Always,[]),
+	   List.map (fun (id,_) -> Term(id,Always,[])) ancmems
+	 ))
       in
       let do_method m (id,_) = (method_label m, Term(id,Always,[]))
       in
@@ -222,10 +282,17 @@ class ['class_type, 'member_type] ccsl_pre_interface_theory
 	Defn( m#get_name, 
 	      [[Declared(name_of_coalgebra, self#coalgebra_type)]],
 	      Function(m#get_domain,m#get_codomain),
-	      RecordSelection( m#last_name,
-			       Application(Term(super_access_method(super),
-						Always,[]), 
-					   coalgebra_term)))
+	      Application( 
+		(if !output_mode = Isa_mode
+		 then
+		   QualifiedTerm( isar_theory_name super, 
+				  Always, [], m#last_name)
+		 else
+		   Term( m#last_name, Always,[])
+		),
+		Application(Term(super_access_method(super),
+				 Always,[]), 
+			    coalgebra_term)))
       in
 	List.map (fun m -> do_method m) acl#get_actions
 
@@ -296,13 +363,8 @@ class ['class_type, 'member_type] ccsl_pre_interface_theory
 	  cl#get_definitions
 
     method make_body =
-      Import( 
-	(match !output_mode with
-	   | Pvs_mode -> []
-	   | Isa_mode -> [isabelle_top_theory, []])
-	@
-	self#component_imports @ self#super_imports @ self#user_imports)
-	::
+      Import(self#all_imports)
+      ::
       self#functor_declaration
       @
       self#constructor_declaration
@@ -361,7 +423,9 @@ class ['class_type, 'member_type] ccsl_pre_coadt_theory
 
     initializer top_theory#override_file_name (ccsl_class_file_name cl)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
     method make_body =
       [Import(
@@ -440,7 +504,9 @@ object (self : 'self)
 		      
   method get_parameters = orig_parameters
 			    
-  method get_proofs = []
+(* ISAR
+ *   method get_proofs = []
+ *)
 			
   method private ltype = TypeConstant((name_of_loose_type cl),Always,[])
 			   
@@ -448,19 +514,27 @@ object (self : 'self)
     TypeArgument(self#ltype) :: orig_arguments
       
   method private lcoalg_type = 
-    Predtype(Formula(
-	       Term(name_of_assert cl,
-		    Always,self#loose_args)))
+    if !output_mode = Isa_mode 
+    then
+      self#coalgebra_type
+    else
+      Predtype(Formula(
+		 Term(name_of_assert cl,
+		      Always,self#loose_args)))
 
   method private lalg_type = 
-    Predtype(Formula(
-	       Application(
-		 Term(name_of_creation cl,Always,
-		      self#loose_args),
-		 Term(name_of_loose_coalgebra cl, Always,[])
-	       )))
+    if !output_mode = Isa_mode 
+    then
+      self#algebra_type
+    else
+      Predtype(Formula(
+		 Application(
+		   Term(name_of_creation cl,Always,
+			self#loose_args),
+		   Term(name_of_loose_coalgebra cl, Always,[])
+		 )))
 
-  method private coalg_model_axiom =
+  method private pvs_coalg_model_axiom =
     Axiom(
       name_of_loose_coalg_axiom,
       Exists(
@@ -471,6 +545,15 @@ object (self : 'self)
 	    coalgebra_term
 	))))
 	    
+  method private isa_coalg_model_axiom =
+    Axiom(
+      name_of_loose_coalg_axiom,
+      Formula(
+	Application(
+	  Term(name_of_assert cl,Always,[]),
+	  Term(name_of_loose_coalgebra cl, Always, [])
+	)))
+	    
 	    
   method private loose_decl = 
     let tcc_proof = 
@@ -487,11 +570,12 @@ object (self : 'self)
     in
       Proved(
 	Defnuninterpret(name_of_loose_coalgebra cl, [], self#lcoalg_type),
-	Named_proof(
-	  (name_of_loose_coalgebra cl) ^ "_TCC1",
-	  tcc_proof))
+	PvsProof(
+	  Named_proof(
+	    (name_of_loose_coalgebra cl) ^ "_TCC1",
+	    tcc_proof)))
 
-  method private alg_model_axiom =
+  method private pvs_alg_model_axiom =
     Axiom(
       name_of_loose_alg_axiom,
       Exists(
@@ -505,6 +589,17 @@ object (self : 'self)
 	      Term(name_of_creation cl,Always,[]),
 	      Term(name_of_loose_coalgebra cl, Always, [])),
 	    algebra_term))))
+
+  method private isa_alg_model_axiom =
+    Axiom(
+      name_of_loose_alg_axiom,
+      Formula(
+	Application(
+	  Application(
+	    Term(name_of_creation cl,Always,[]),
+	    Term(name_of_loose_coalgebra cl, Always, [])),
+	  Term(name_of_algebra_loose cl, Always, [])
+	)))
 	    
   method private loose_private_bisim_eq_decl =
     Defn( name_of_loose_private_bisim_eq cl, [],
@@ -525,19 +620,41 @@ object (self : 'self)
 	    Tuple([Term(name_of_loose_coalgebra cl,Always,[])])))
       
   method make_body =
-    [Typevardecl (name_of_loose_type cl);
-     Import( [ccsl_basic_theory_name cl, self#loose_args]);
-     self#coalg_model_axiom;
-     self#loose_decl;
-    ]
-    @
-    if cl#has_constructors 
-    then 
-      [self#alg_model_axiom;
-       Defnuninterpret(name_of_algebra_loose cl, [], self#lalg_type);
-      ]
-    else 
-      []
+    if !output_mode = Isa_mode
+    then
+      (
+	[Typevardecl(orig_parameters, name_of_loose_type cl);
+	 Import( [ccsl_basic_theory_name cl, self#loose_args]);
+	 self#loose_decl;
+	 self#isa_coalg_model_axiom;
+	]
+	@
+	if cl#has_constructors 
+	then 
+	  [
+	   Defnuninterpret(name_of_algebra_loose cl, [], self#lalg_type);
+	    self#isa_alg_model_axiom;
+	  ]
+	else 
+	  []
+      )
+    else
+      (
+	[Typevardecl (orig_parameters, name_of_loose_type cl);
+	 Import( [ccsl_basic_theory_name cl, self#loose_args]);
+	 self#pvs_coalg_model_axiom;
+	 self#loose_decl;
+	]
+	@
+	if cl#has_constructors 
+	then 
+	  [self#pvs_alg_model_axiom;
+	   Defnuninterpret(name_of_algebra_loose cl, [], self#lalg_type);
+	  ]
+	else 
+	  []
+      )
+
     
 end
   
@@ -578,7 +695,9 @@ object (self : 'self)
 		      
   method get_parameters = orig_parameters
 			    
-  method get_proofs = []
+(* ISAR
+ *   method get_proofs = []
+ *)
 			
   method private ftype = TypeConstant((name_of_final_type cl),Always,[])
 			   
@@ -592,22 +711,30 @@ object (self : 'self)
       ]);
 
   method private fcoalg_type = 
-    Predtype(
-      Formula(
-	Term(name_of_assert cl,
-	     Always,
-	     TypeArgument(self#ftype) :: orig_arguments));
-    )
+    if !output_mode = Isa_mode 
+    then
+      self#coalgebra_type
+    else
+      Predtype(
+	Formula(
+	  Term(name_of_assert cl,
+	       Always,
+	       TypeArgument(self#ftype) :: orig_arguments));
+      )
 
   method private falg_type = 
-    Predtype(Formula(
-	       Application(
-		 Term(name_of_creation cl,Always,
-		      TypeArgument(self#ftype) :: orig_arguments),
-		 Term(name_of_final_coalgebra cl, Always,[])
-	       )))
+    if !output_mode = Isa_mode 
+    then
+      self#algebra_type
+    else
+      Predtype(Formula(
+		 Application(
+		   Term(name_of_creation cl,Always,
+			TypeArgument(self#ftype) :: orig_arguments),
+		   Term(name_of_final_coalgebra cl, Always,[])
+		 )))
 
-  method private coalg_model_axiom =
+  method private pvs_coalg_model_axiom =
     Axiom(
       name_of_final_coalg_axiom,
       Exists(
@@ -618,6 +745,15 @@ object (self : 'self)
 	    coalgebra_term
 	))))
 	    
+  method private isa_coalg_model_axiom =
+    Axiom(
+      name_of_final_coalg_axiom,
+      Formula(
+	Application(
+	  Term(name_of_assert cl,Always,[]),
+	  Term(name_of_final_coalgebra cl, Always, [])
+	)))
+	    
 	    
   method private final_decl = 
     let tcc_proof = 
@@ -634,11 +770,12 @@ object (self : 'self)
     in
       Proved(
 	Defnuninterpret(name_of_final_coalgebra cl, [], self#fcoalg_type),
-	Named_proof(
-	  (name_of_final_coalgebra cl) ^ "_TCC1",
-	  tcc_proof))
+	PvsProof(
+	  Named_proof(
+	    (name_of_final_coalgebra cl) ^ "_TCC1",
+	    tcc_proof)))
 
-  method private alg_model_axiom =
+  method private pvs_alg_model_axiom =
     Axiom(
       name_of_final_alg_axiom,
       Exists(
@@ -654,22 +791,54 @@ object (self : 'self)
 	    algebra_term
 	  ))))
 	    
+  method private isa_alg_model_axiom =
+    Axiom(
+      name_of_final_alg_axiom,
+      Formula(
+	Application(
+	  Application(
+	    Term(name_of_creation cl,Always,[]),
+	    Term(name_of_final_coalgebra cl, Always, [])),
+	  Term(name_of_algebra_final cl, Always, [])
+	)))
+	    
 	    
   method make_body =
-    [Typevardecl (name_of_final_type cl);
-     self#do_import;
-     self#coalg_model_axiom;
-     self#final_decl
-    ]
-    @
-    if cl#has_constructors 
+    if !output_mode = Isa_mode
     then
-      [
-	self#alg_model_axiom;
-	Defnuninterpret(name_of_algebra_final cl, [], self#falg_type);
-      ]
-    else 
-      []
+      (
+	[Typevardecl (orig_parameters, name_of_final_type cl);
+	 self#do_import;
+	 self#final_decl;
+	 self#isa_coalg_model_axiom;
+	]
+	@
+	if cl#has_constructors 
+	then
+	  [
+	    Defnuninterpret(name_of_algebra_final cl, [], self#falg_type);
+	    self#isa_alg_model_axiom;
+	  ]
+	else 
+	  []
+      )
+    else
+      (
+	[Typevardecl (orig_parameters, name_of_final_type cl);
+	 self#do_import;
+	 self#pvs_coalg_model_axiom;
+	 self#final_decl
+	]
+	@
+	if cl#has_constructors 
+	then
+	  [
+	    self#pvs_alg_model_axiom;
+	    Defnuninterpret(name_of_algebra_final cl, [], self#falg_type);
+	  ]
+	else 
+	  []
+      )
     
 end
   
@@ -710,7 +879,9 @@ object (self : 'self)
 		      
   method get_parameters = self#simple_parameters
 			    
-  method get_proofs = []
+(* ISAR
+ *   method get_proofs = []
+ *)
 			
   method private ftype = TypeConstant((name_of_final_type cl),Always,[])
 			   
@@ -725,13 +896,23 @@ object (self : 'self)
       ]);
 
   method private coalg_model_axiom =
-    Axiom(
-      name_of_final_prop_axiom cl,
-      Formula(
+    let inner_ex =
+      if !output_mode = Isa_mode 
+      then
+	Application(
+	  Application(
+	    Term(name_of_finality cl,Always,[]),
+	    Term(name_of_final_coalgebra cl, Always, [])),
+	  Term("arbitrary", Always, []))
+      else
 	Application(
 	  Term(name_of_finality cl,Always,[]),
 	  Term(name_of_final_coalgebra cl, Always, [])
-	)))
+	)
+    in
+      Axiom(
+	name_of_final_prop_axiom cl,
+	Formula( inner_ex ))
 	    
 	    
   method make_body =
