@@ -18,16 +18,22 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Friday 5 July 02 18:25:54 tews@ithif51>
  *
  * the ccsl interface theory
  *
- * $Id: interface_theory.mli,v 1.4 2002/05/03 15:01:09 tews Exp $
+ * $Id: interface_theory.mli,v 1.5 2002/07/18 13:43:22 tews Exp $
  *
  *)
 
 open Classtypes
 
+class ccsl_isar_start_class
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
+class ccsl_isar_close_class
+  : ccsl_iface_type -> ccsl_sig_theory_type
+
 class ccsl_interface_theory 
   : ccsl_iface_type ->  ccsl_class_theory_type 
 
