@@ -18,11 +18,11 @@
  *
  * * Created 15.1.99 by Hendrik
  *
- * Time-stamp: <Monday 24 June 02 17:42:07 tews@ithif51>
+ * Time-stamp: <Friday 5 July 02 18:25:54 tews@ithif51>
  *
  * main compiler driver
  *
- * $Id: main.ml,v 1.18 2002/07/03 12:01:15 tews Exp $
+ * $Id: main.ml,v 1.19 2002/07/18 13:43:22 tews Exp $
  *
  *)
 
@@ -80,6 +80,7 @@ let pvs_prelude =
    End list
   ";;
 
+
 let isa_prelude = 
   "
    Begin list[ X : Type ] : Adt
@@ -280,24 +281,26 @@ let ccsl_pass =
 
 
 let ccsl_parse_prelude () =
-  let do_ccsl_prelude s =
+  let parse_prelude_part s =
     print_verbose "    Reading prelude";
     let prelude_ast =
-      ccsl_pass (Lexing.from_string s) in
-    print_verbose "    Parsing done ...";
-    prelude_ast in
+      ccsl_pass (Lexing.from_string s) 
+    in
+      print_verbose "    Parsing done ...";
+      prelude_ast 
+  in
   let _ = parsing_prelude := true in
   let _ = parsing_builtin_prelude := true in
   let _ = Abstract_lexer.initialize "Backend specific prelude" in
   let pvs_p_ast = 
-    do_ccsl_prelude 
+    parse_prelude_part 
 	(match !output_mode with
 	   | Pvs_mode -> pvs_prelude 
 	   | Isa_mode -> isa_prelude)
   in
   let _ = parsing_builtin_prelude := false in
   let _ = Abstract_lexer.initialize "CCSL prelude" in
-  let ccsl_p_ast = do_ccsl_prelude ccsl_prelude in
+  let ccsl_p_ast = parse_prelude_part ccsl_prelude in
   let _ = parsing_prelude := false 
   in
     pvs_p_ast @ ccsl_p_ast;;
@@ -339,28 +342,41 @@ let ccsl_selected_classes_filter ast =
     ast;;
 
 
+(* let ccsl_theory_list ast =
+ *   List.fold_left
+ *     (fun res ast_el ->
+ * 	  let prelude_flag = ref false in 
+ * 	  let newths = match ast_el with
+ * 	    | CCSL_class_dec cl -> 
+ * 		prelude_flag := cl#belongs_to_prelude;
+ * 		cl#generate_all_theories
+ * 	    | CCSL_adt_dec adt -> 
+ * 		prelude_flag := adt#belongs_to_prelude;
+ * 		adt#generate_all_theories
+ * 	    | CCSL_sig_dec si -> 
+ * 		prelude_flag := si#belongs_to_prelude;
+ * 		si#generate_all_theories
+ * 	  in 
+ * 	    if !prelude_flag then
+ * 	      List.iter (fun th -> th#override_file_name Names.ccsl_prelude_name)
+ * 		newths;
+ * 	    res @ newths
+ *     )
+ *     []
+ *     ast;;
+ *)
+
+
 let ccsl_theory_list ast =
-  List.fold_left
-    (fun res ast_el ->
-       let prelude = ref false in 
-       let newths = match ast_el with
-	 | CCSL_class_dec cl -> 
-	     prelude := cl#belongs_to_prelude;
-	     cl#generate_all_theories
-	 | CCSL_adt_dec adt -> 
-	     prelude := adt#belongs_to_prelude;
-	     adt#generate_all_theories
-	 | CCSL_sig_dec si -> 
-	     prelude := si#belongs_to_prelude;
-	     si#generate_all_theories
-       in 
-	 if !prelude then
-	   List.iter (fun th -> th#override_file_name Names.ccsl_prelude_name)
-	     newths;
-	 res @ newths
-    )
-    []
-    ast;;
+  List.flatten 
+    (List.map
+       (function
+	  | CCSL_class_dec cl -> cl#generate_all_theories
+	  | CCSL_adt_dec adt -> adt#generate_all_theories
+	  | CCSL_sig_dec si -> si#generate_all_theories
+       )
+       ast)
+;;
 
 
 let make_ccsl_isabelle_file_name th =
@@ -381,9 +397,10 @@ let ccsl_output_theories thl =
 	  Syntax.pvs_output thl
     | Isa_mode ->
 	print_verbose "    Isabelle output mode";
-      	List.iter
-	  make_ccsl_isabelle_file_name
-	  thl;
+(* 	   List.iter
+ * 	     make_ccsl_isabelle_file_name
+ * 	     thl;
+ *)
       	if !generate_batch
       	then
 					(* Pvs_batch works also for isabelle *)
@@ -392,7 +409,7 @@ let ccsl_output_theories thl =
       	then
 	  Syntax.do_proof_test thl
       	else
-	  Syntax.isabelle_output thl;;
+	  Syntax.isar_output thl;;
 
 
 
@@ -456,14 +473,24 @@ let do_ccsl_ast ast =
 
 let do_ccsl_prelude () =
   let dl = get_debug_level () in
-  let empty_type_ths = 
+  let start_prelude_ths = 
     if !output_mode = Pvs_mode 
     then
       [ new Emptytype_theory.ccsl_empty_type_theory;
 	new Emptytype_theory.ccsl_empty_fun_theory;
       ]
     else
-      []
+      [
+	new Emptytype_theory.ccsl_isar_start_prelude;
+	new Emptytype_theory.ccsl_isabelle_addon_theory;
+      ]
+  in let end_prelude_ths = 
+    if !output_mode = Pvs_mode 
+    then []
+    else
+      [
+	new Emptytype_theory.ccsl_isar_close_prelude;
+      ]
   in
     if not (debug_level _DEBUG_PRELUDE) then
       begin
@@ -477,9 +504,11 @@ let do_ccsl_prelude () =
       ignore(Symbol.close_block());
       assert( Symbol.nesting_size() = 0 );
       ignore(Symbol.start_block());
-      if (empty_type_ths <> []) & (not !selected_classes_only) then
-	ccsl_output_theories empty_type_ths;
+      if (start_prelude_ths <> []) & (not !selected_classes_only) then
+	ccsl_output_theories start_prelude_ths;
       do_ccsl_ast all_p_ast;
+      if (end_prelude_ths <> []) & (not !selected_classes_only) then
+	ccsl_output_theories end_prelude_ths;
       add_debug_level dl;
       assert( Symbol.nesting_size() = 1 )
       
