@@ -18,11 +18,11 @@
  *
  * Created 16.03.00 by Jan
  *
- * Time-stamp: <Monday 24 June 02 10:19:45 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 17:04:34 tews@ithif51>
  *
  * Coalgebra morphism theories
  *
- * $Id: morphism_theory.ml,v 1.12 2002/07/03 12:01:15 tews Exp $
+ * $Id: morphism_theory.ml,v 1.13 2002/07/18 13:43:23 tews Exp $
  *
  *)
 
@@ -237,9 +237,9 @@ class ['class_type, 'member_type] ccsl_pre_morphism_theory
 	     [decl1_list; decl2_list; [ Undeclared(f, type_of_morphism) ]],
 	     Bool,
 	     Application(
-	       Application(
+	       SmartApplication(
 		 Term(name_of_full_morphism_pred cl, Always, []),
-		 Tuple([c1_tuple; c2_tuple])
+		 [c1_tuple; c2_tuple]
 	       ),
 	       Term(f,Always,[])
 	     ))
@@ -256,7 +256,9 @@ class ['class_type, 'member_type] ccsl_pre_morphism_theory
 	self#public_morphism_decl
       ]
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 end
 
@@ -324,26 +326,22 @@ class ['class_type, 'member_type] ccsl_pre_morphism_rewrite_theory
 	  Iff(
 	    Formula(
 	      Application(
-	    	Application(
+	    	SmartApplication(
 		  Term(name_of_full_morphism_pred cl, 
 		       Isabelle_only, 
 		       self#double_self_arguments),
-		  Tuple(
 		    [coalgebra1_term;coalgebra2_term]
-		  )
 	    	),
 	    	Term(f,Never,[])
 	      )
 	    ),
 	    Formula(
 	      Application(
-		Application(
+		SmartApplication(
 		  Term(name_of_private_bibisimulation cl,
 		       Isabelle_only,
 		       self#double_self_arguments),
-		  Tuple(
 		    [coalgebra1_term;coalgebra2_term]
-		  )
 		),
 		Application(
 		  Term(name_of_graph,Never,[]),
@@ -372,13 +370,11 @@ class ['class_type, 'member_type] ccsl_pre_morphism_rewrite_theory
 	    Implies(
 	      Formula(
 		Application(
-		  Application(
+		  SmartApplication(
 		    Term(name_of_full_morphism_pred cl, 
 			 Isabelle_only, 
 			 self#double_self_arguments),
-		    Tuple(
 		      [coalgebra1_term;coalgebra2_term]
-		    )
 	    	  ),
 	    	  Term(f,Never,[])
 	      	)
@@ -412,7 +408,9 @@ class ['class_type, 'member_type] ccsl_pre_morphism_rewrite_theory
 	 self#do_method
 	 cl#get_all_actions)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 end
 
@@ -470,6 +468,7 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
 
     method private finality_existence_decl =
       let sub_ns = sub_space ns in
+      let unused_x = create_id_with_preference sub_ns "x" "x" in
       let type_of_morphism = 	  
 	Function(
 	  BoundTypeVariable(self1),
@@ -478,33 +477,42 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
       in
       let f = create_one_id sub_ns type_of_morphism in
       	Defn( name_of_finality_existence cl,
-	      [[Declared(name_of_coalgebra2,
-			 self#assert_coalgebra2_type)]],
+	      [(Declared(name_of_coalgebra2, self#coalgebra2_type)) ::
+				(* add a variable for isabelle to bind Self1 *)
+		 if !output_mode = Isa_mode
+		 then
+		   [Undeclared(unused_x, BoundTypeVariable self1)]
+		 else
+		   []
+	      ],
 	      Bool,
 	      Expression(
 	       	Forall(
-		  [name_of_coalgebra1,self#assert_coalgebra1_type],
-		  Exists(
-		    [f,type_of_morphism],
+		  [name_of_coalgebra1,self#coalgebra1_type],
+		  Implies(
 		    Formula(
 		      Application(
-		       	Application(
-			  Term(name_of_full_morphism_pred cl,
-			       Isabelle_only,
-			       self#double_self_arguments),
-			  Tuple([coalgebra1_term;
-				 coalgebra2_term])
-		       	),
-		       	Term(f,Never,[])
-		      )
-		    )
-		  )
-	       	)
-	      )
-	    )
+			Term(name_of_assert cl, Always,
+			     self#self1_argument :: orig_arguments),
+			coalgebra1_term
+		      )),
+		    Exists(
+		      [f,type_of_morphism],
+		      Formula(
+			Application(
+		       	  SmartApplication(
+			    Term(name_of_full_morphism_pred cl,
+				 Isabelle_only,
+				 self#double_self_arguments),
+			    [coalgebra1_term; coalgebra2_term]
+		       	  ),
+		       	  Term(f,Never,[])
+			)))
+		  ))))
 	  
     method private finality_uniqueness_decl = 
       let sub_ns = sub_space ns in
+      let unused_x = create_id_with_preference sub_ns "x" "x" in
       let type_of_morphism = 	  
 	Function(
 	  BoundTypeVariable(self1),
@@ -516,60 +524,109 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
       let is_morph fn = 
 	Formula(
 	  Application(
-	    Application(
+	    SmartApplication(
 	      Term(name_of_full_morphism_pred cl,
 		   Isabelle_only,
 		   self#double_self_arguments),
-	      Tuple([coalgebra1_term;
-		     coalgebra2_term])),
+	      [coalgebra1_term; coalgebra2_term]),
 	    Term(fn,Never,[]))) 
       in
       	Defn( name_of_finality_uniqueness cl,
-	      [[Declared(name_of_coalgebra2,
-			 self#assert_coalgebra2_type)]],
+	      [(Declared(name_of_coalgebra2, self#coalgebra2_type)) ::
+				(* add a variable for isabelle to bind Self1 *)
+		 if !output_mode = Isa_mode
+		 then
+		   [Undeclared(unused_x, BoundTypeVariable self1)]
+		 else
+		   []
+	      ],
 	      Bool,
 	      Expression(
 	       	Forall(
 		  [name_of_coalgebra1,
-		   self#assert_coalgebra1_type],
+		   self#coalgebra1_type],
 		  Forall(
 		    [f, type_of_morphism;
 		     g, type_of_morphism],
 		    Implies(
-		      And([ (is_morph f); (is_morph g) ]),
+		      And([ 
+			    Formula(
+			      Application(
+				Term(name_of_assert cl, Always,
+				     self#self1_argument :: orig_arguments),
+				coalgebra1_term
+			      ));
+			    (is_morph f); 
+			    (is_morph g) 
+			  ]),
 		      Equal(
 			Term(f,Never,[]),
 			Term(g,Never,[])
 		      ))))))
 	
+
     method private finality_decl =
-      Defn( name_of_finality cl,
-	    [[Declared(name_of_coalgebra2, self#assert_coalgebra2_type)]],
-	    Bool,
-	    Expression(
-	      And(
-		[
-		  Formula(
-		    Application(
-		      Term(name_of_assert cl, Always,
-			   self#self2_argument :: orig_arguments),
-		      coalgebra2_term
-		    ));			    
-		  Formula(
-		    Application(
-		      Term(name_of_finality_existence cl, Never, []),
-		      coalgebra2_term
-		    )
-		  );
-		  Formula(
-		    Application(
-		      Term(name_of_finality_uniqueness cl, Never, []),
-		      coalgebra2_term
-		    ))]
-	      )))
+      let sub_ns = sub_space ns in
+      let unused_x = create_id_with_preference sub_ns "x" "x" in
+      let final_ex = 
+	if !output_mode = Isa_mode 
+	then
+	  Formula(
+	    Application(
+	      Application(
+		Term(name_of_finality_existence cl, Never, []),
+		coalgebra2_term),
+	      Term(unused_x, Always, [])
+	    ))
+	else
+	  Formula(
+	    Application(
+	      Term(name_of_finality_existence cl, Never, []),
+	      coalgebra2_term
+	    ))
+      in let final_un = 
+	if !output_mode = Isa_mode 
+	then
+	  Formula(
+	    Application(
+	      Application(
+		Term(name_of_finality_uniqueness cl, Never, []),
+		coalgebra2_term),
+	      Term(unused_x, Always,[])
+	    ))
+	else
+	  Formula(
+	    Application(
+	      Term(name_of_finality_uniqueness cl, Never, []),
+	      coalgebra2_term
+	    ))
+      in
+	Defn( name_of_finality cl,
+	      [(Declared(name_of_coalgebra2, self#coalgebra2_type)) ::
+				(* add a variable for isabelle to bind Self1 *)
+		 if !output_mode = Isa_mode
+		 then
+		   [Undeclared(unused_x, BoundTypeVariable self1)]
+		 else
+		   []
+	      ],
+	      Bool,
+	      Expression(
+		And(
+		  [
+		    Formula(
+		      Application(
+			Term(name_of_assert cl, Always,
+			     self#self2_argument :: orig_arguments),
+			coalgebra2_term
+		      ));
+		    final_ex;
+		    final_un
+		  ]
+		)))
 
 
-    method private struct_coreduce_def = 
+    method private pvs_struct_coreduce_def = 
 	    (* (""
 	     *  (SKOLEM-TYPEPRED)
 	     *  (EXPAND* "nonempty?" "empty?" "member" "Project_final?"
@@ -577,6 +634,7 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
 	     *  (FLATTEN)
 	     *  (HIDE-ALL-BUT (-3 -5))
 	     *  (INST?)
+	     *  (ASSERT)
 	     *  (SKOSIMP)
 	     *  (INST?))
              *)
@@ -588,6 +646,7 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
 	  flatten;
 	  hide_all_but [-3; -5];
 	  inst_question;
+	  pvs_assert;
 	  skosimp;
 	  inst_question
 	]
@@ -611,21 +670,52 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
 	  Abstraction(
 	    [f, type_of_morphism],
 	    Application(
-	      Application(
+	      SmartApplication(
 		Term(name_of_full_morphism_pred cl,
 		     Isabelle_only,
 		     self#double_self_arguments),
-		Tuple([coalgebra1_term;
-		       coalgebra2_term])),
+		[coalgebra1_term; coalgebra2_term]),
 	      Term(f,Never,[])))
 	))
       in
 	Proved(decl,
-	       Named_proof((name_of_class_struct_coreduce cl) ^ "_TCC1",
-			   tcc_proof))
+	       PvsProof(
+		 Named_proof((name_of_class_struct_coreduce cl) ^ "_TCC1",
+			     tcc_proof)))
+
+
+    method private isa_struct_coreduce_def = 
+      let sub_ns = sub_space ns in
+      let type_of_morphism = 	  
+	Function(
+	  BoundTypeVariable(self1),
+	  BoundTypeVariable(self2)
+      	)
+      in let f = create_one_id sub_ns type_of_morphism 
+      in let decl = 
+	  Defn(
+	    name_of_class_struct_coreduce cl,
+	    [[Undeclared(name_of_coalgebra2, self#coalgebra2_type)];
+	     [Undeclared(name_of_coalgebra1,self#coalgebra1_type)]],
+	    type_of_morphism,
+	    Application(
+	      Term(name_of_choose(), Always,[]),
+	      Abstraction(
+		[f, type_of_morphism],
+		Application(
+		  SmartApplication(
+		    Term(name_of_full_morphism_pred cl,
+			 Isabelle_only,
+			 self#double_self_arguments),
+		    [coalgebra1_term; coalgebra2_term]),
+		  Term(f,Never,[])))
+	))
+      in
+	decl
 		     
 
-    method private coreduce_def = 
+
+    method private pvs_coreduce_def = 
       let sub_ns = sub_space ns in
       let type_of_morphism = 	  
 	Function(
@@ -667,22 +757,98 @@ class ['class_type, 'member_type] ccsl_pre_finality_theory
 	))
       in 
 	Proved(decl,
-	       Named_proof((name_of_class_coreduce cl) ^ "_TCC1",
-			   tcc_proof))
+	       PvsProof(
+		 Named_proof((name_of_class_coreduce cl) ^ "_TCC1",
+			   tcc_proof)))
+
+
+    method private isa_coreduce_def = 
+      let sub_ns = sub_space ns in
+      let type_of_morphism = 	  
+	Function(
+	  BoundTypeVariable(self1),
+	  BoundTypeVariable(self2)
+      	)
+      in let f = create_one_id sub_ns type_of_morphism in
+      let m_tuple = create_id_with_preference sub_ns "m_tuple" "p" in
+      let (decl_list, _) = self#coalgebra_as_tuple sub_ns in
+      let tuple_type = 
+	Product(
+	  List.map (function
+		      | Undeclared(_, typ) -> 
+			  substitute_types_only eq_ccsl_types 
+			    [(Self, BoundTypeVariable(self1))]
+			    typ
+		      | _ -> assert false)
+		  decl_list
+	)
+      in let tuple_size = List.length decl_list in
+      let i = ref 0 in
+      let mterm_list =
+	List.map 
+	  (fun _ -> 
+	     incr i;
+	     Application(
+	       Projection(!i, tuple_size),
+	       Term(m_tuple, Always, []))
+	  )
+	  decl_list  
+      in let decl = 
+	  Defn(
+	    name_of_class_coreduce cl,
+	    [[Undeclared(name_of_coalgebra2, self#coalgebra2_type)];
+	     [Undeclared(m_tuple, tuple_type )]],
+	    type_of_morphism,
+	    Application(
+	      Application(
+		Term(name_of_class_struct_coreduce cl,Always,[]),
+		coalgebra2_term),
+	      SmartApplication(
+		Term(name_of_struct_of cl, Always,[]),
+		mterm_list)
+	    ))
+      in 
+	decl
 
 
     method make_body = 
       [
       	self#imports;
 	self#coalgebra2_decl;
+      ]
+      @ (
+	if !output_mode = Isa_mode 
+	then
+	  [Comment( "The next definitions contains an unused variable\n" ^
+		    "on the left hand side to bind the type variable\n" ^
+		    "'Self1"
+		  )
+	  ]
+	else
+	  []
+      ) @
+      [
 	self#finality_existence_decl;
 	self#finality_uniqueness_decl;
 	self#finality_decl;
-	self#struct_coreduce_def;
-	self#coreduce_def
       ]
+	@ (
+	  if !output_mode = Isa_mode
+	  then
+	    [
+	      self#isa_struct_coreduce_def;
+	      self#isa_coreduce_def
+	    ]
+	  else
+	    [
+	      self#pvs_struct_coreduce_def;
+	      self#pvs_coreduce_def
+	    ]
+	)
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 end
 
@@ -741,13 +907,26 @@ class ['class_type, 'member_type] ccsl_pre_finality_bisim_theory
       let x1_term = Term(x1,Never,[]) in
       let x2_term = Term(x2,Never,[]) in
       let final_assum typ = 
-	Formula(
-	  Application(
-	    Term(name_of_finality cl, Always, 
-		 (TypeArgument typ) :: self#simple_arguments),
-	    coalgebra_term
+	if !output_mode = Isa_mode
+	then
+	  Formula(
+	    Application(
+	      Application(
+		Term(name_of_finality cl, Always, 
+		     (TypeArgument typ) :: self#simple_arguments),
+		coalgebra_term),
+	      TypedTerm(
+		Term("arbitrary", Always, []),
+		typ)
+	    ))
+	else
+	  Formula(
+	    Application(
+	      Term(name_of_finality cl, Always, 
+		   (TypeArgument typ) :: self#simple_arguments),
+	      coalgebra_term
+	    )
 	  )
-	)
       in
 	Lemma(
 	  name_of_finality_bisim_eq_lemma cl,
@@ -762,7 +941,7 @@ class ['class_type, 'member_type] ccsl_pre_finality_bisim_theory
 		Formula(
 		  Application(
 		    Application(
-		      Term(name_of_private_bibisim cl,
+		      Term(name_of_private_bisim_eq cl,
 			   Isabelle_only,
 			   (self#self2_argument :: orig_arguments)
 			  ),
@@ -784,7 +963,9 @@ class ['class_type, 'member_type] ccsl_pre_finality_bisim_theory
 	self#finality_bisim_eq_lemma;
       ]
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 end
 
@@ -899,11 +1080,13 @@ class ['class_type, 'member_type] ccsl_pre_map_struct_theory
 	  component_imports
 	)
 
-    method private coalgebra_decl =
-      let (args_from,_) = self#double_arguments 
-      in
-	Vardecl(name_of_coalgebra, 
-		IFace( cl, Always, self_argument :: args_from))
+
+(*     method private coalgebra_decl =
+ * 	 let (args_from,_) = self#double_arguments 
+ * 	 in
+ * 	   Vardecl(name_of_coalgebra, 
+ * 		   IFace( cl, Always, self_argument :: args_from))
+ *)
 
 
     val mutable fun_ids_var_field = None
@@ -1092,13 +1275,11 @@ class ['class_type, 'member_type] ccsl_pre_map_struct_theory
 	)
 
 
-	  (* this override changes also assert_coalgebra_decl ! *)
-    method assert_coalgebra_type = 
+	  (* this override changes also coalgebra_decl ! *)
+    method coalgebra_type = 
       let from_args,_ = self#double_arguments 
       in
-      Predtype(Formula(Term(name_of_assert cl,
-			    Always,
-			    self_argument :: from_args)))
+	IFace( cl, Always, self_argument :: from_args)
 
 
     method private do_admissable =
@@ -1117,17 +1298,25 @@ class ['class_type, 'member_type] ccsl_pre_map_struct_theory
       in
 	Defn(
 	  name_of_admissable_map_fun_pred cl,
-	  ([Declared(name_of_coalgebra, self#assert_coalgebra_type)] ::
+	  ([Declared(name_of_coalgebra, self#coalgebra_type)] ::
 	     if fun_ids = [] 
 	     then []
 	     else
 	       [(List.map (fun (id,t) -> Declared(id,t)) fun_ids)]),
 	  Bool,
-	  Application(
-	    Term(name_of_assert cl, Always, self_argument :: to_args),
-	    Application(
-	      struct_body,
-	      coalgebra_term)))
+	  Expression(
+	    Implies(
+	      Formula(
+		Application(
+		  Term(name_of_assert cl, Always, self_argument :: from_args),
+		  coalgebra_term)),
+	      Formula(
+		Application(
+		  Term(name_of_assert cl, Always, self_argument :: to_args),
+		  Application(
+		    struct_body,
+		    coalgebra_term)))
+	  )))
 
 
     method make_body = 
@@ -1136,11 +1325,13 @@ class ['class_type, 'member_type] ccsl_pre_map_struct_theory
       @
       [
 	self#class_map_struct;
-	self#assert_coalgebra_decl;
+	self#coalgebra_decl;
 	self#do_admissable;
       ]
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 end
 
@@ -1205,6 +1396,13 @@ class ['class_type, 'member_type] ccsl_pre_map_theory
 	TypeConstant(name_of_final_type cl, Always, args_from ) in
       let cl_to = 
 	TypeConstant(name_of_final_type cl, Always, args_to) in
+      let funs_name = create_id_with_preference ns "funs" "f" in
+
+      let fun_ids =		(* only needed for Isabelle *)
+	  variance_flatten self#fun_ids_var
+      in
+      let fun_exprs = List.map (fun (id,t) -> Term(id,Always,[])) fun_ids 
+      in
       let funs_type = 
 	Predtype(
 	  Formula(
@@ -1213,16 +1411,21 @@ class ['class_type, 'member_type] ccsl_pre_map_theory
 		   TypeArgument(cl_from) :: args_from @ args_to),
 	      Term(name_of_final_coalgebra cl, Always, args_from))))
       in
-      let funs_name = create_id_with_preference ns "funs" "f"
-      in
       let pre_body = 
 	if args_from = []		(* no type parameters *)
 	then
 	  Term(name_of_class_map_struct cl, Always,[])
 	else
-	  Application(
-	    Term(name_of_class_map_struct cl, Always,[]),
-	    Term(funs_name,Always,[]))
+	  if !output_mode = Isa_mode 
+	  then
+	    SmartApplication(
+	      Term(name_of_class_map_struct cl, Always,[]),
+	      fun_exprs
+	    )
+	  else
+	    Application(
+	      Term(name_of_class_map_struct cl, Always,[]),
+	      Term(funs_name,Always,[]))
       in let body =
 	  Application(
 	    pre_body,
@@ -1234,7 +1437,11 @@ class ['class_type, 'member_type] ccsl_pre_map_theory
 	  (if args_from = []		(* no type parameters *)
 	   then []
 	   else
-	     [[Undeclared(funs_name, funs_type)]]
+	     if !output_mode = Isa_mode
+	     then
+	       [(List.map (fun (id,t) -> Undeclared(id,t)) fun_ids)]
+	     else
+	       [[Undeclared(funs_name, funs_type)]]
 	  ),
 					(* the type *)
 	  Function(cl_from, cl_to),
@@ -1258,7 +1465,9 @@ class ['class_type, 'member_type] ccsl_pre_map_theory
 	self#class_map
       ]
 
-    method get_proofs = []
+(* ISAR
+ *     method get_proofs = []
+ *)
 
 end
 
