@@ -18,11 +18,11 @@
  *
  * Created 9.5.00 by Jan
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Monday 24 June 02 9:59:40 tews@ithif51>
  *
  * the ccsl morphisms
  *
- * $Id: morphism_theory.mli,v 1.4 2002/05/03 15:01:11 tews Exp $
+ * $Id: morphism_theory.mli,v 1.5 2002/07/03 12:01:15 tews Exp $
  *
  *)
 
@@ -37,6 +37,9 @@ class ccsl_morphism_rewrite_theory
 class ccsl_finality_theory
   : ccsl_iface_type ->  ccsl_class_theory_type 
 
+class ccsl_finality_bisim_theory
+  : ccsl_iface_type ->  ccsl_class_theory_type 
+
 class ccsl_map_struct_theory
   : ccsl_iface_type ->  ccsl_class_theory_type 
 
