@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 25 June 02 10:46:03 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 15:58:04 tews@ithif51>
  *
  * strings for ccsl translation
  *
- * $Id: names.ml,v 1.11 2002/07/03 12:01:15 tews Exp $
+ * $Id: names.ml,v 1.12 2002/07/18 13:43:23 tews Exp $
  *
  *)
 
@@ -159,6 +159,10 @@ let ccsl_empty_type_defn_theory_name = "EmptyTypeDef"
 
 let ccsl_empty_fun_theory_name = "EmptyFun"
 
+(* addons for Isabelle *)
+
+let ccsl_isabelle_addon_theory_name = "IsabelleAddon"
+
 let ccsl_prelude_name = "ccsl_prelude"
 
 (*******************************************************************
@@ -355,7 +359,7 @@ let name_of_public_invariance cl =
 let name_of_method_invariance cl =
   match !output_mode with
 		| Pvs_mode -> "method_invariant?"
-		| Isa_mode -> "method_invariant"
+		| Isa_mode -> cl#get_name ^ "_method_invariant"
 
 let name_of_greatest_invariance cl =
   match !output_mode with
@@ -364,9 +368,16 @@ let name_of_greatest_invariance cl =
 
 let name_of_h_gi = "H_gi"
 
-let name_of_box = "box"
+let name_of_box cl = 
+  match !output_mode with
+    | Pvs_mode -> "box"
+    | Isa_mode -> cl#get_name ^ "_box"
+
+let name_of_diamond cl = 
+  match !output_mode with
+    | Pvs_mode -> "diamond"
+    | Isa_mode -> cl#get_name ^ "_diamond"
 
-let name_of_diamond = "diamond"
 
 let name_of_monotonic = 
   match !output_mode with
@@ -380,6 +391,10 @@ let name_of_nonempty =
  
 let name_of_gfp = "gfp"
 
+let name_of_set2pred = "set2pred"
+
+let name_of_pred2set = "Collect"
+
 let name_of_admissible =
   match !output_mode with
     | Pvs_mode -> "admissible?"
@@ -420,7 +435,7 @@ let name_of_list_member () =
 let name_of_choose () =
   match !output_mode with
     | Pvs_mode -> "choose"
-    | Isa_mode -> "choose"
+    | Isa_mode -> "Eps"
 
 let name_of_assertion_predicate ass = 
   match !output_mode with
@@ -653,20 +668,28 @@ let name_of_finality_bisim_eq_lemma cl =
  * file names
  *)
 
-let ccsl_class_file_name cl = cl#get_name ^ "_basic"
+let ccsl_file_name iface = iface#get_name ^ "_basic"
+
+let ccsl_class_file_name = ccsl_file_name
 
 let ccsl_class_theorem_file_name cl = cl#get_name ^ "_theorem"
 
-let ccsl_box_file_name cl = cl#get_name ^ "_basic"
+let ccsl_adt_file_name = ccsl_file_name
 
-let ccsl_adt_file_name adt = adt#get_name ^ "_basic"
-
-let ccsl_sig_file_name si = si#get_name ^ "_basic"
+let ccsl_sig_file_name = ccsl_file_name
 
 let name_of_pvs_ccsl_lib = "ccsllib"
 
 let name_of_fixedpoints = "fixedpoints"
 
+let isar_theory_name iface =
+  if iface#belongs_to_prelude 
+  then
+    ccsl_prelude_name
+  else
+    ccsl_file_name iface
+    
+
 (*** Local Variables: ***)
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
