@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 24 June 02 9:59:40 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 15:54:51 tews@ithif51>
  *
  * strings for ccsl translation
  *
- * $Id: names.mli,v 1.11 2002/07/03 12:01:15 tews Exp $
+ * $Id: names.mli,v 1.12 2002/07/18 13:43:23 tews Exp $
  *
  *)
 
@@ -137,6 +137,10 @@ val ccsl_empty_type_defn_theory_name : string
 
 val ccsl_empty_fun_theory_name : string
 
+(* addons for Isabelle *)
+
+val ccsl_isabelle_addon_theory_name : string
+
 val ccsl_prelude_name : string
 
 (*******************************************************************
@@ -269,9 +273,9 @@ val name_of_greatest_invariance: <get_name : string; .. > -> string
 
 val name_of_h_gi: string
 
-val name_of_box: string
+val name_of_box: <get_name : string; .. > -> string
 
-val name_of_diamond: string
+val name_of_diamond: <get_name : string; .. > -> string
 
 val name_of_admissible: string
 
@@ -299,6 +303,10 @@ val name_of_nonempty: string
 
 val name_of_gfp: string
 		
+val name_of_set2pred : string
+
+val name_of_pred2set : string
+
 val name_of_initially : <get_name : string; .. > -> string
 
     (* Use name_of_list_member always with SmartApplication, 
@@ -468,10 +476,6 @@ val ccsl_class_file_name : <get_name : string; .. > -> string
 
 val ccsl_class_theorem_file_name : <get_name : string; .. > -> string
 
-(*
-val ccsl_box_file_name: <get_name : string; .. > -> string
-*)
-
 val ccsl_adt_file_name : <get_name : string; .. > -> string
 
 val ccsl_sig_file_name : <get_name : string; .. > -> string
@@ -480,7 +484,10 @@ val name_of_pvs_ccsl_lib : string
 
 val name_of_fixedpoints : string
 
-
+val isar_theory_name :
+  <get_name : string;
+   belongs_to_prelude : bool;
+   .. > -> string
 
 
 
