@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Monday 24 June 02 16:52:04 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 21:22:38 tews@ithif56.inf.tu-dresden.de>
  *
  * Typechecking with unification
  *
- * $Id: newtypecheck.ml,v 1.17 2002/07/03 12:01:16 tews Exp $
+ * $Id: newtypecheck.ml,v 1.18 2002/07/18 13:43:23 tews Exp $
  *
  *
  * the algorithm is homegrown and works in two passes
@@ -662,13 +662,13 @@ let rec check_expression ccl loc tv_bindings expr_typ expr =
 	  end
 	  
 			(* ex_typ is normalized, see derive_expression *)
-      | MethodSelection(TypeAnnotation(ex,ex_typ), typeopt, m) ->
+      | MethodSelection(TypeAnnotation(ex,ex_typ), instiface, m) ->
 	  let _ = 
 	    iter_components_add_component ccl ex_typ
 	  in 
 	    MethodSelection(
 	      TypeAnnotation(recurse_exp ex_typ ex, ex_typ), 
-	      typeopt, m) 
+	      instiface, m) 
 
 				(* MethodSelection needs TypeAnnotation *)
       | MethodSelection _ ->
@@ -912,8 +912,6 @@ let rec check_expression ccl loc tv_bindings expr_typ expr =
       | Map _
       | SmartAbstraction _
       | SmartApplication _
-      | Comment_str _
-      | Comment_expr _
       | Comprehension _ ->
 	  assert(false)
 	  in 
@@ -1124,10 +1122,10 @@ let rec derive_expression ccl loc tv_bindings expr =
 	     utyp_ex)
 
 					      (* we are in derive_expression *)
-      | MethodSelection(ex, instifaceopt, m) ->
+      | MethodSelection(ex, instiface, m) ->
 	  let _ = dr "MethodSelection" in
 	  let nex, typ_ex = recurse_exp ex in
-	  let utyp = match instifaceopt with
+	  let utyp = match instiface with
 	    | InstIface (iface,args,instloc) -> 
 		assert(iface#is_class);
 		do_unify typ_ex (Class(iface,args)) (wrong_object_type loc)
@@ -1179,17 +1177,18 @@ let rec derive_expression ccl loc tv_bindings expr =
 		   then undefined_method cl mtoken
 		     (remove_option mtoken.loc)) in
 					      (* we are in derive_expression *)
-	  let typ = match nutyp with
-	    | Self -> m#get_curried_type
+	  let typ,ninstiface = match nutyp with
+	    | Self -> (m#get_curried_type, CurrentIface)
 	    | Class(cl,args) -> 
-		snd( export_member_with_args cl m args m#get_curried_type )
+		(snd( export_member_with_args cl m args m#get_curried_type ),
+		 InstIface(cl, args, None))
 	    | _ -> assert(false)
 	  in let _ = dr ("Resolve " ^ m#get_name ^ ": " ^
 			 m#hosting_class#get_name)
 	  in
 	    (MethodSelection(
 	       TypeAnnotation(nex, nutyp),
-	       instifaceopt, Resolved m),
+	       ninstiface, Resolved m),
 	     typ)
 
       | Tuple(ex_list) -> 
@@ -1437,8 +1436,6 @@ let rec derive_expression ccl loc tv_bindings expr =
       | Map _
       | SmartAbstraction _
       | SmartApplication _
-      | Comment_str _
-      | Comment_expr _
       | Comprehension _ ->
 	  assert(false)
   in 
@@ -1650,8 +1647,6 @@ let rec check_valid_definition_expr loc expr =
       | Map _
       | SmartAbstraction _
       | SmartApplication _
-      | Comment_str _
-      | Comment_expr _
       | Comprehension _ ->
 	  assert(false)
 	
