@@ -18,11 +18,11 @@
  *
  * Created 1.10.97 by Hendrik
  *
- * Time-stamp: <Sunday 23 June 02 14:38:41 tews@ithif56.inf.tu-dresden.de>
+ * Time-stamp: <Tuesday 16 July 02 10:09:03 tews@ithif51>
  *
  * Utility functions for ccsl parser
  *
- * $Id: parser.ml,v 1.25 2002/07/03 12:01:16 tews Exp $
+ * $Id: parser.ml,v 1.26 2002/07/18 13:43:24 tews Exp $
  *
  *)
 
@@ -522,29 +522,34 @@ let do_adt_end startloc end_id =
   let adt = cadt() in
   let _ = match adt#get_adt_constructors with
     | [] -> (error_message (new_loc startloc (remove_option end_id.loc))
-	       ("An adt must contain at least one constructor." );
+	       ("An Adt must contain at least one constructor." );
 	     raise Parsing.Parse_error
 	    )
     | _ -> ()
   in
-  let name = adt#get_name in
-  let tv = FreeTypeVariable(Type_variable.fresh()) in 
-  let subst = [ Carrier, tv  ] in
-  let do_const_type const = ccsl_substitute_types subst const#get_full_type in
-  let reduce_arg_typ = match adt#get_adt_constructors with
-    | [ c ] -> do_const_type c
-    | cl -> Product(List.map do_const_type cl)
+  let name = adt#get_name 
   in
-  let reduce_type = Function( reduce_arg_typ, Function(Carrier, tv))
-  in
-  let reduce_tok = {token_name = (Names.name_of_adt_reduce adt);
-		    loc = None};
-  in
-  let reduce_mem = new ccsl_pre_member_class (ciface()) reduce_tok []
-		     (Product[]) reduce_type
-		     NoVisibility Adt_Reduce
-  in
-    add_member_to_iface reduce_mem;
+
+(* in class methods pass now
+ *   let tv = FreeTypeVariable(Type_variable.fresh()) in 
+ *   let subst = [ Carrier, tv  ] in
+ *   let do_const_type const = ccsl_substitute_types subst const#get_full_type in
+ *   let reduce_arg_typ_list = List.map do_const_type adt#get_adt_constructors 
+ *   in
+ *   let reduce_type = 
+ *     SmartFunction(
+ * 	 reduce_arg_typ_list,
+ * 	 Function(Carrier, tv))
+ *   in
+ *   let reduce_tok = {token_name = (Names.name_of_adt_reduce adt);
+ * 		       loc = None};
+ *   in
+ *   let reduce_mem = new ccsl_pre_member_class (ciface()) reduce_tok []
+ * 			(Product[]) reduce_type
+ * 			NoVisibility Adt_Reduce
+ *   in
+ *     add_member_to_iface reduce_mem;
+ *)
     check_closing_id name end_id;
     current_iface := Parse_Nothing;
     ignore(Symbol.close_block ());
