@@ -18,11 +18,11 @@
  *
  * Created 16.November 1999 by Jan
  *
- * Time-stamp: <Monday 11 March 02 11:40:45 tews@ithif51>
+ * Time-stamp: <Wednesday 17 July 02 17:56:11 tews@ithif51>
  *
  * convert CCSL specifics into HOL for the pretty printer
  *
- * $Id: pre_printing.ml,v 1.12 2002/05/03 15:01:12 tews Exp $
+ * $Id: pre_printing.ml,v 1.13 2002/07/18 13:43:24 tews Exp $
  *
  *)
 
@@ -54,6 +54,29 @@ let stupid_make_n_ids n =
 let rec ccsl_pre_pretty_list pretty_fun l = List.map pretty_fun l
 
 
+let member_term ooselection ciface instiface name = 
+  if !output_mode = Pvs_mode 
+  then
+    Term(name, Always, [])
+  else
+    let (memcl, in_source) = 
+      match instiface with
+	| InstIface(cl, args, Some loc) -> (cl, true)
+					(* no annotiontion from source *)
+	| InstIface(cl, args, None) ->  (cl, false)
+	| CurrentIface -> (ciface, false)
+
+(* HENDRIK: fix update assertions to generate proper instantiated ifaces *)
+	| NoIface -> (* assert false *)
+	    (ciface, false)
+    in
+      if in_source || (ooselection && (memcl#get_name <> ciface#get_name))
+      then
+	QualifiedTerm(isar_theory_name memcl, Always, [], name)
+      else
+	Term(name, Always, [])
+
+
 (* Argument member_fun delivers a algebra (a coalgebra respectively) 
  * for a given member. Argument iface_fun does the same for a class.
  * Then the pre_prettyprinting can do its main 
@@ -68,7 +91,7 @@ let rec ccsl_pre_pretty_basic_expressions ciface member_fun iface_fun =
     | TermVar _ as exp	-> BasicExpr(exp)
 
 	(* optional class is ignored, because method is resolved *)
-    | Member(typeoption, mem) ->
+    | Member(instiface, mem) ->
 	let rom = resolution_of mem in
 	let name_of_member  = rom#get_name 
 	in
@@ -79,15 +102,18 @@ let rec ccsl_pre_pretty_basic_expressions ciface member_fun iface_fun =
 		then
 		  Term("( " ^ name_of_member ^ " )", Always, [])
 		else
-		  Term(name_of_member, Always, [])
+		  member_term false ciface instiface name_of_member
 	    | Spec_class ->
 		(match member_fun rom with
-		   | Some suit -> RecordSelection(name_of_member, suit )
-		   | None -> Term(name_of_member, Always, [])
+		   | Some suit -> 
+		       (* RecordSelection(name_of_member, suit ) *)
+		       Application(
+			 member_term false ciface instiface name_of_member,
+			 suit)
+		   | None -> member_term false ciface instiface name_of_member
 		)
 	    | Spec_Spec -> assert(false)
-	    
-	  
+
 
 and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
   let recurse_ex = ccsl_pre_pretty_expression ciface member_fun iface_fun in
@@ -104,7 +130,7 @@ and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
       | QualifiedTerm _ 	-> exp
 	  
 		(* optional class is ignored, because method is resolved *)
-      | MethodSelection (ex, typeoption, mem) ->
+      | MethodSelection (ex, instiface, mem) ->
 	  let rmem = (resolution_of mem) in
 	  let ncoalg = 
 	    (* only real methods in MethodSelection 
@@ -112,12 +138,14 @@ and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
 	     *)
 	    remove_option (member_fun rmem) in
 	  let name_of_method  = rmem#get_name in
-	  let nex = recurse_ex ex 
+	  let nex = recurse_ex ex in
+	  let mem_term = 
+	    Application(
+	      member_term true ciface instiface name_of_method,
+	      ncoalg)
 	  in 
 	    (match rmem#get_domain with
-	       | Self -> (Application(
-			    RecordSelection(name_of_method, ncoalg),
-			    nex))
+	       | Self -> (Application(mem_term, nex))
 	       | Product(Self :: typ_list) -> 
 		   let ids = stupid_make_n_ids (List.length typ_list) in
 		   let terms = List.map (fun s -> Term(s,Never,[])) ids 
@@ -125,14 +153,14 @@ and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
 		     Abstraction( 
 		       List.combine ids typ_list, 
 		       Application(
-			 RecordSelection(name_of_method, ncoalg),
+			 mem_term,
 			 Tuple(nex :: terms)))
 	       | _ -> assert(false)
 	    )
 	    
 		(* optional class is ignored, because method is resolved *)
       | Application(TypeAnnotation(
-		      ExprLoc(MethodSelection(ex, cl, m),_),
+		      ExprLoc(MethodSelection(ex, instiface, m),_),
 		      _), ExprLoc(arg,_)) 
 	  when (resolution_of m)#get_domain <> Self ->
 	  let arg_list = match arg with
@@ -147,11 +175,16 @@ and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
 	    remove_option (member_fun rmem) in
 	  let name_of_method = rmem#get_name in
 	  let nex = recurse_ex ex in
+	  let mem_term = 
+	    Application(
+	      member_term true ciface instiface name_of_method,
+	      ncoalg)
+	  in 
 	  let nargs = ccsl_pre_pretty_list 
 			(recurse_ex) arg_list
 	  in 
 	    Application(
-	      RecordSelection(name_of_method, ncoalg),
+	      mem_term,
 	      Tuple(nex :: nargs))
 	      
       | Tuple(l)		-> 
@@ -295,12 +328,14 @@ and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
  *)
       | Box(typ, ex, tl) ->
 	  let nex = recurse_ex ex in
-	  let meth_list = List.map (fun m -> Term(m.token_name ,Always,[])) tl
+	  let meth_list = 
+	    List.map (fun m -> Term(name_of_method_tag_string m.token_name, 
+				    Always,[])) tl
 	  in
 	    Application(
 	      Application(
 		Application(
-		  Term(name_of_box, Always, []),
+		  Term(name_of_box ciface, Always, []),
 		  iface_fun typ
 		),
 		List(meth_list)
@@ -309,12 +344,14 @@ and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
 	    )
       | Diamond(typ, ex, tl) ->
 	  let nex = recurse_ex ex in
-	  let meth_list = List.map (fun m -> Term(m.token_name,Always,[])) tl
+	  let meth_list = 
+	    List.map (fun m -> Term(name_of_method_tag_string m.token_name, 
+				    Always,[])) tl
 	  in
 	    Application(
 	      Application(
 		Application(
-		  Term(name_of_diamond, Always, []),
+		  Term(name_of_diamond ciface, Always, []),
 		  iface_fun typ
 		),
 		List(meth_list)
@@ -346,13 +383,6 @@ and ccsl_pre_pretty_expression ciface member_fun iface_fun exp =
       | Expression(f)	->
 	  let nef = recurse_form f in
 	      Expression(nef)
-      | Comment_str(s,ex)   ->
-	  let nex = recurse_ex ex in
-	      Comment_str(s,nex)
-      | Comment_expr(ex1,t,ex2) ->
-	  let nex1 = recurse_ex ex1 in
-	  let nex2 = recurse_ex ex2 in
-	      Comment_expr(nex1,t,nex2)
       | Comprehension(s,t,f) ->
 	  let nef = recurse_form f in
 	      Comprehension(s,t,nef)
