@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 13:45:33 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 10:15:44 tews@ithif51>
  *
- * generic class for all ccsl class and adt theories
+ * generic classes for all ccsl class and adt theories
  *
- * $Id: theory_class.ml,v 1.14 2002/05/22 13:42:44 tews Exp $
+ * $Id: theory_class.ml,v 1.15 2002/07/18 13:43:25 tews Exp $
  *
  *)
 
@@ -66,7 +66,7 @@ open Logic_util
 
 
 class virtual ['class_type, 'member_type ] ccsl_pre_theory_body_class 
-  cl 
+  (cl : 'class_type)
   (* the equality relation for initializing the name space *)
   (eq_types : ('class_type, 'member_type) top_pre_types
      -> ('class_type, 'member_type) top_pre_types -> bool)
@@ -332,11 +332,13 @@ class virtual ['class_type, 'member_type ]
 
     method assert_coalgebra1_type = 
       Predtype(Formula(Term(name_of_assert cl,
-			    Always,self#self1_argument :: orig_arguments)))
+ 			    Always,self#self1_argument :: orig_arguments)))
 
-    method assert_coalgebra2_type = 
-      Predtype(Formula(Term(name_of_assert cl,
-			    Always,self#self2_argument :: orig_arguments)))
+(* ISAR
+ *     method assert_coalgebra2_type = 
+ * 	 Predtype(Formula(Term(name_of_assert cl,
+ * 			       Always,self#self2_argument :: orig_arguments)))
+ *)
 
       (* This is a bit strange! Since we model the algebra functor
        * as Record of functions (instead of a sum of the domains) the 
@@ -365,11 +367,13 @@ class virtual ['class_type, 'member_type ]
     method assert_coalgebra_decl =
       Vardecl(name_of_coalgebra, self#assert_coalgebra_type)
 
-    method assert_coalgebra1_decl =
-      Vardecl(name_of_coalgebra1, self#assert_coalgebra1_type)
-
-    method assert_coalgebra2_decl =
-      Vardecl(name_of_coalgebra2, self#assert_coalgebra2_type)
+(* ISAR
+ *     method assert_coalgebra1_decl =
+ * 	 Vardecl(name_of_coalgebra1, self#assert_coalgebra1_type)
+ * 
+ *     method assert_coalgebra2_decl =
+ * 	 Vardecl(name_of_coalgebra2, self#assert_coalgebra2_type)
+ *)
 
       (* the algebra declaration *)
     method algebra_decl = 
@@ -388,12 +392,9 @@ class virtual ['class_type, 'member_type ]
       let decl_list = 
 	List.map (fun (name,typ) -> Undeclared(name,typ)) mems in
       let coalgebra_from_tuple =
-	Application(
+	SmartApplication(
 	  Term(name_of_struct_of cl, Always,[]),
-	  match mems with
-	    | [(id,_)] -> Term(id,Always,[])
-	    | l -> Tuple(
-		List.map (fun (id,_) -> Term(id,Always,[])) l)
+	  List.map (fun (id,_) -> Term(id,Always,[])) mems
 	)
       in
 	decl_list, coalgebra_from_tuple
@@ -424,12 +425,9 @@ class virtual ['class_type, 'member_type ]
       let decl2_list = 
 	List.map (fun (name,typ) -> Undeclared(name,typ)) s2_names in
       let make_coalgebra mems =
-	Application(
+	SmartApplication(
 	  Term(name_of_struct_of cl, Always,[]),
-	  match mems with
-	    | [(id,_)] -> Term(id,Always,[])
-	    | l -> Tuple(
-		List.map (fun (id,_) -> Term(id,Always,[])) l)
+	  List.map (fun (id,_) -> Term(id,Always,[])) mems
 	) in
       let c1_from_tuple = make_coalgebra s1_names in
       let c2_from_tuple = make_coalgebra s2_names 
@@ -492,7 +490,7 @@ class ccsl_method_inv_helper_class (cl: 'class_type)
 	| Some ms -> ms
 	| None -> 
 	    let methods = 
-	      List.filter (fun m -> m#needs_lifting && m#is_method) 
+	      List.filter (fun m -> m#is_method && m#needs_lifting) 
 		cl#get_all_members
 	    in
 	      lifting_methods <- Some methods;
@@ -541,6 +539,49 @@ class virtual ['class_type, 'member_type ] ccsl_pre_sig_theory_class
   end
 
 
+
+(*******************************************************************
+ *******************************************************************
+ *
+ * Isabelle Starters/Stoppers
+ *
+ *)
+
+class ['class_type, 'member_type] 
+  ccsl_pre_isabelle_delimiter_theory_class 
+  (cl : 'class_type) 
+  (eq_types : ('class_type, 'member_type) top_pre_types
+     -> ('class_type, 'member_type) top_pre_types -> bool)
+  delimiter 
+  (file_name : string)
+  (isar_imports : string list)
+  : ['class_type, 'member_type] ccsl_pre_sig_theory_type
+  =
+  object (self : 'self)
+    inherit 
+      ['class_type, 'member_type] ccsl_pre_sig_theory_class cl eq_types
+      as top_theory
+
+    method get_name = "Isabelle Delimiter theory"
+
+    method get_parameters = []
+
+    initializer top_theory#override_file_name file_name
+
+    method make_body = []
+
+    method kind = match delimiter with
+      | IsabelleStartFile
+      | IsabelleCloseFile -> delimiter
+      | Theory
+      | Datatype -> assert false
+
+    method get_isar_imports = isar_imports
+
+end (* ccsl_isabelle_delimiter_theory_class *)
+
+  
+
 (*** Local Variables: ***)
 (*** version-control: t ***)
 (*** kept-new-versions: 5 ***)
