@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 14:17:56 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 10:45:04 tews@ithif51>
  *
  * Utility functions for ccsl input types
  *
- * $Id: types_util.ml,v 1.23 2002/05/22 13:42:44 tews Exp $
+ * $Id: types_util.ml,v 1.24 2002/07/18 13:43:25 tews Exp $
  *
  *)
 
@@ -271,6 +271,92 @@ and args_have_successor_state args =
     args
 
 
+(*******************************************************************
+ *
+ * curry an Adt constructor type to convert it for Isabelle 
+ *
+ *)
+
+
+let curry_constructor_type typ = match typ with
+  | Function (Product(args), res) -> 
+      List.fold_right 
+	(fun arg accu -> Function(arg, accu))
+	args
+	res
+
+  | Function _
+  | Groundtype _ 
+  | BoundTypeVariable _ 
+  | Self 
+  | Bool 
+  | Product _
+  | Class _ 
+  | Adt _
+  | Carrier
+  | Predtype _
+  | Record _
+  | IFace _
+  | Array _ 	      
+  | FreeTypeVariable _
+  | TypeConstant _
+  | SmartFunction _ 
+    -> typ
+
+
+(*******************************************************************
+ *
+ * replace SmartFunction with iterated Function's or Products,
+ * depending on Global.output_mode
+ * 
+ * needed for normalizing types during typechecking
+ *)
+
+
+let rec unsmart_type typ = match typ with
+  | Groundtype(idrec, args) 	-> Groundtype(idrec, unsmart_args args)
+  | BoundTypeVariable _ 	-> typ
+  | FreeTypeVariable _		-> typ
+  | Self			-> typ
+  | Carrier 			-> typ
+  | Bool 			-> typ
+  | Function( dom, codom) 	-> 
+      Function(unsmart_type dom, unsmart_type codom)
+  | Product( types ) 		-> Product(List.map unsmart_type types)
+  | Class(cl, args )		-> Class(cl, unsmart_args args)
+  | Adt(adt, flag, args )	-> Adt(adt, flag, unsmart_args args)
+		(* do records as an exception *)
+  | Record label_list 		->
+      Record( List.map (fun (name,typ) -> (name, unsmart_type typ)) label_list)
+					(* not in ccsl input types *)
+  | SmartFunction( doml, codom) ->
+      let ndoml = List.map unsmart_type doml in
+      let ncodom = unsmart_type codom 
+      in
+	(match ndoml with
+	   | [] -> assert false
+	   | [t] -> Function(t, ncodom)
+	   | _ -> 
+	       if !Global.output_mode = Isa_mode 
+	       then
+		 List.fold_right
+		   (fun t accu -> Function(t, accu))
+		   ndoml
+		   ncodom
+	       else
+		 Function(Product(ndoml), ncodom)
+	)
+
+  | TypeConstant _
+  | IFace _
+  | Array _
+  | Predtype _
+    -> assert(false)
+
+and unsmart_args args = 
+  List.map (function TypeArgument t -> TypeArgument( unsmart_type t)) args
+
+    
 (*******************************************************************
  *
  * utility functions for ground types (more below)
@@ -807,12 +893,6 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
        List.for_all2 eq_ccsl_expressions expr_list1 expr_list2)      
   | Expression(formula1), Expression(formula2) ->
       eq_ccsl_formulas formula1 formula2
-  | Comment_str(c1, ex1), Comment_str(c2, ex2) ->
-      (* do not compare the comments *)
-      eq_ccsl_expressions ex1 ex2
-  | Comment_expr( cex1,ctyp1, ex1), Comment_expr( cex2,ctyp2, ex2) ->
-      (* do not compare the comments *)
-      eq_ccsl_expressions ex1 ex2
   | Comprehension(name1, typ1, fo1),Comprehension(name2, typ2, fo2) ->
       (eq_string name1 name2)
       && (eq_ccsl_types typ1 typ2)
@@ -850,8 +930,6 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
   | RelEvery _, _
   | Map _, _
   | Expression _ ,_
-  | Comment_str _ ,_
-  | Comment_expr _ ,_
   | Comprehension _ ,_
 
   | _, BasicExpr _
@@ -881,8 +959,6 @@ and eq_ccsl_expressions e1 e2 =   e1 == e2 or match e1,e2 with
   | _, RelEvery _
   | _, Map _
   | _, Expression _
-  | _, Comment_str _
-  | _, Comment_expr _
   | _, Comprehension _ 
       -> false
 
