@@ -18,11 +18,11 @@
  *
  * Created 14.5.99 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 14:20:26 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 10:42:21 tews@ithif51>
  *
  * Utility functions for ccsl input types
  *
- * $Id: types_util.mli,v 1.12 2002/05/22 13:42:44 tews Exp $
+ * $Id: types_util.mli,v 1.13 2002/07/18 13:43:25 tews Exp $
  *
  *)
 
@@ -107,6 +107,25 @@ val occur_check : Type_variable.t -> ('cl, 'mem) top_pre_types  -> bool
 val has_successor_state : ('cl, 'mem) top_pre_types -> bool
 
 
+
+    (********
+     * curry an Adt constructor type to convert it for Isabelle 
+     *)
+val curry_constructor_type : 
+  ('cl, 'mem) top_pre_types -> ('cl, 'mem) top_pre_types 
+
+
+    (***************
+     *
+     * replace SmartFunction with iterated Function's or Products,
+     * depending on Global.output_mode
+     * 
+     * needed for normalizing types during typechecking
+     *)
+
+val unsmart_type : ('cl, 'mem) top_pre_types -> ('cl, 'mem) top_pre_types 
+
+
 (***********************************************************************
  *
  * iter_components walks through the type and applies action 
