@@ -22,7 +22,7 @@
  *
  * part of global.ml that is configurable
  *
- * $Id: config.ml,v 1.2 2002/05/03 15:01:16 tews Exp $
+ * $Id: config.ml,v 1.3 2002/07/18 13:43:26 tews Exp $
  *
  *)
 
@@ -32,7 +32,7 @@
  * Should be the same as LIBDIR in ../Makefile.
  *)
 
-let fixedpointlib = "/usr/local/lib/ccsl/pvs"
+let fixedpointlib = "/home/tews/Privat/tmp/Ccslc/Lib/Pvs"
 
 
 (*** Local Variables: ***)
