@@ -18,11 +18,11 @@
  *
  * Created 26.1.99 by Hendrik
  *
- * Time-stamp: <Monday 8 October 01 17:58:00 tews@ithif51>
+ * Time-stamp: <Monday 24 June 02 17:44:56 tews@ithif51>
  *
  * printing error messages
  *
- * $Id: error.ml,v 1.5 2002/05/03 15:01:16 tews Exp $
+ * $Id: error.ml,v 1.6 2002/07/03 12:01:17 tews Exp $
  *
  *)
 
@@ -105,6 +105,10 @@ let error_message loc s =
   flush stderr;; 
 
   
+let pedantic_error loc s =
+  error_message loc ("Pedantic error: " ^ s);
+  raise PedanticViolation
+
 
 (*** Local Variables: ***)
 (*** version-control: t ***)
