@@ -18,11 +18,11 @@
  *
  * Created 11.11.99 by Hendrik
  *
- * Time-stamp: <Friday 21 June 02 16:39:25 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 21:28:04 tews@ithif56.inf.tu-dresden.de>
  *
  * substitution and optimization for top_types
  *
- * $Id: logic_util.ml,v 1.21 2002/07/03 12:01:17 tews Exp $
+ * $Id: logic_util.ml,v 1.22 2002/07/18 13:43:27 tews Exp $
  *
  *)
 
@@ -172,6 +172,7 @@ let rec substitute_types ((eq_typ,_) as eqs) ((typ_sub,_) as subst) typ =
 	   | Bool -> typ
 	   | Self -> typ
 	   | Carrier -> typ
+					       (* we are in substitute_types *)
 	   | Function(dom,codom) -> 
 	       let ndom = recurse_type dom in
 	       let ncodom = recurse_type codom in
@@ -194,6 +195,7 @@ let rec substitute_types ((eq_typ,_) as eqs) ((typ_sub,_) as subst) typ =
 		 if nargs == args 
 		 then typ 
 		 else Class(cl,nargs)
+					       (* we are in substitute_types *)
 	   | Adt(adt,flag,args) -> 
 	       let nargs = recurse_args args in
 		 if nargs == args 
@@ -217,6 +219,7 @@ let rec substitute_types ((eq_typ,_) as eqs) ((typ_sub,_) as subst) typ =
 		 if labels == nlabels 
 		 then typ
 		 else Record(nlabels)
+					       (* we are in substitute_types *)
 	   | IFace(cl,arg_flag,args) ->
 	       let nargs = recurse_args args in
 		 if nargs == args 
@@ -263,6 +266,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if ex==ex' && typ==typ' 
 		 then expr
 		 else TypedTerm(ex', typ')
+					  (* we are in substitute_expression *)
 	   | TypeAnnotation(ex, typ) ->
 	       let ex' = recurse_exp ex in
 	       let typ' = recurse_type typ in
@@ -288,6 +292,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 else Tuple nex_list		 
 	   | Projection(i,n) -> expr
 
+					  (* we are in substitute_expression *)
 	   | RecordTuple(fields) -> 
 	       let nfields = 
 		 substitute_list
@@ -320,6 +325,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if ex == nex && changes == nchanges 
 		 then expr
 		 else RecordUpdate(nex,nchanges)
+					  (* we are in substitute_expression *)
 	   | List(ex_list) ->
 	       let nex_list = substitute_list recurse_exp ex_list in 
 		 if ex_list == nex_list 
@@ -345,6 +351,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		     if nex == ex 
 		     then expr
 		     else SmartAbstraction(decl_list,nex)
+					  (* we are in substitute_expression *)
 	   | Application(ex1,ex2) -> 
 	       let nex1 = recurse_exp ex1 in
 	       let nex2 = recurse_exp ex2 in
@@ -379,6 +386,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if fex == nfex && changes == nchanges 
 		 then expr
 		 else FunUpdate(nfex,nchanges)
+					  (* we are in substitute_expression *)
 	   | Let(decl_list, ex) ->
 		   (* Let binds sequentially, so I use substitute_list
                     * to mimic a fold_right, that collects the
@@ -408,6 +416,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if decl_list == ndecl_list && ex == nex 
 		 then expr
 		 else Let(ndecl_list,nex)
+					  (* we are in substitute_expression *)
 	   | If(conds,ex) ->
 	       let nconds = 
 		 substitute_list
@@ -442,6 +451,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if ex == nex && variants == nvariants 
 		 then expr
 		 else Case(nex, nvariants)
+					  (* we are in substitute_expression *)
 	   | CCSL_Case(ex,variants) -> 
 	       let nex = recurse_exp ex in
 	       let nvariants = 
@@ -475,6 +485,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if n_typ == typ && n_pred == pred then
 		   expr
 		 else Diamond(typ,n_pred,tlist)
+					  (* we are in substitute_expression *)
 	   | Every(typ, form_list) -> 
 	       let ntyp = recurse_type typ in
 	       let nform_list = substitute_list recurse_exp form_list in
@@ -498,18 +509,7 @@ and substitute_expression ((_,eq_ex) as eqs) ((_,ex_sub) as subst) expr =
 		 if form == nform 
 		 then expr
 		 else Expression nform
-	   | Comment_str(s,ex) -> 
-	       let nex = recurse_exp ex in
-		 if ex == nex 
-		 then expr
-		 else Comment_str(s,nex)
-	   | Comment_expr(ex1,typ,ex2) -> 
-	       let nex1 = recurse_exp ex1 in
-	       let ntyp = recurse_type typ in
-	       let nex2 = recurse_exp ex2 in
-		 if ex1 == nex1 && typ == ntyp && ex2 == nex2 
-		 then expr
-		 else Comment_expr(nex1,ntyp,nex2)
+					  (* we are in substitute_expression *)
 	   | Comprehension(s,typ,form) -> 
 	       let ntyp = recurse_type typ in
 	       let nsubst = bind_vars subst [s] in
@@ -552,6 +552,7 @@ and substitute_formula eqs subst formula =
 	   if nf_list == f_list 
 	   then formula
 	   else Or nf_list
+					     (* we are in substitute_formula *)
      | Implies(assum,concl) -> 
 	 let nassum = recurse_form assum in
 	 let nconcl = recurse_form concl in
@@ -577,6 +578,7 @@ and substitute_formula eqs subst formula =
 	   if f == nf 
 	   then formula
 	   else Forall(quant_list,nf)
+					     (* we are in substitute_formula *)
      | Exists(quant_list, f) -> 
 	 let ids = List.map fst quant_list in
 	 let nsubst = bind_vars subst ids in
@@ -603,6 +605,7 @@ and substitute_formula eqs subst formula =
 	   if f == nf 
 	   then formula
 	   else MetaForall(quant_list,nf)
+					     (* we are in substitute_formula *)
      | Bisim(typ,ex1,ex2) -> 
 	 let typ1 = recurse_type typ in
 	 let nex1 = recurse_exp ex1 in
@@ -779,8 +782,6 @@ let rec occurs_free_in_expression id expr =
        | Map(typ, expr_list) ->
 	   List.exists recurse_exp expr_list
        | Expression form -> recurse_form form 
-       | Comment_str(s,ex) -> recurse_exp ex
-       | Comment_expr(ex1,typ,ex2) -> recurse_exp ex2
        | Comprehension(s,typ,form) -> 
 	   if id = s then false
 	   else recurse_form form
@@ -1168,9 +1169,6 @@ and do_opt_expression = function
   | Let (ll, ex) ->
       Let (List.map (fun (s,t,e) -> (s,t, do_opt_expression e)) ll,
 	   do_opt_expression ex)
-  | Comment_str(s, ex) -> Comment_str(s,do_opt_expression ex)
-  | Comment_expr(ex1,t,ex2) ->
-      Comment_expr(do_opt_expression ex1,t,do_opt_expression ex2)
   | Every(typ, pred_list) ->
       Every(typ, (List.map do_opt_expression pred_list))
   | Map(typ, expr_list) ->
