@@ -18,11 +18,11 @@
  *
  * Created 26.2.99 by Bart
  *
- * Time-stamp: <Friday 24 May 02 11:09:05 tews@ithif51>
+ * Time-stamp: <Tuesday 16 July 02 10:09:03 tews@ithif51>
  *
  * PVS pretty printer
  *
- * $Id: pvs_pretty.ml,v 1.22 2002/05/30 13:10:31 tews Exp $
+ * $Id: pvs_pretty.ml,v 1.23 2002/07/18 13:43:27 tews Exp $
  *
  *)
 
@@ -346,8 +346,11 @@ and pvs_pp_top_expression (* : top_expressions -> unit *)
 	  print_string " :)";
 	  close_box()
 	end
-    | ( SmartAbstraction _
-    | Abstraction _ ) as arg ->
+
+    | 
+      ( SmartAbstraction _
+        | Abstraction _ ) 
+	as arg ->
 	let (str_typ_list, expr) = 
 	  (match arg with
 	     | SmartAbstraction (str_typ_list, expr) -> (str_typ_list, expr)
@@ -727,27 +730,6 @@ and pvs_pp_top_expression (* : top_expressions -> unit *)
     | Expression form ->
 	pvs_pp_top_formula form
 
-    | Comment_str (str, expr) ->
-	begin
-	  force_newline ();
-	  List.iter
-	    (fun s ->
-	       begin
-		 print_string "% ";
-		 print_string s;
-		 force_newline()
-	       end)
-	    (split_on_newline str);
-	  pvs_pp_top_expression expr;
-	  force_newline()
-	end
-    | Comment_expr (expr1, typ, expr2) ->
-	pvs_pp_top_expression
-	  (Comment_str(
-	     (stringwrapper pvs_pp_top_expression expr1)^
-	     " : " ^ 
-	     (stringwrapper pvs_pp_top_type typ),
-	     expr2))
     | Comprehension (str, typ, form) ->
 	begin
 	  open_box 0;
@@ -998,7 +980,8 @@ and pvs_pp_top_theory_declaration (* : top_theory_declaration -> unit *)
 	  pvs_pp_top_type typ;
 	  close_box()
 	end
-    | Typevardecl name ->
+				(* typeparameters are ignored for Pvs *)
+    | Typevardecl(typeparameters, name) ->
 	begin
 	  open_box 0;
 	  print_string (name ^ " : TYPE");
@@ -1211,6 +1194,9 @@ and pvs_pp_top_theory_declaration (* : top_theory_declaration -> unit *)
     | Proved (decl, proof) -> (* proofs are treated somewhere else *)
 	pvs_pp_top_theory_declaration decl
 
+	  (* ignore Isar ML code *)
+    | IsarML _ -> ()
+
 
 and pvs_pp_param_list param_list =
   let pp_param = function
@@ -1288,6 +1274,9 @@ let pvs_pp_theory th =
 	  force_newline();
           close_box()					(* 1 *)
 	end
+					(* ignore Isabelle delimiters *)
+    | IsabelleStartFile
+    | IsabelleCloseFile -> ()
 
 (******************************************************************
  ******************************************************************
