@@ -18,11 +18,11 @@
  *
  * Created 22.4.99 by Bart
  *
- * Time-stamp: <Thursday 16 May 02 17:14:07 tews@ithif51>
+ * Time-stamp: <Thursday 4 July 02 18:05:25 tews@ithif51>
  *
  * top level class structure
  *
- * $Id: top_classes.ml,v 1.15 2002/05/22 13:42:47 tews Exp $
+ * $Id: top_classes.ml,v 1.16 2002/07/18 13:43:28 tews Exp $
  *
  *)
 
@@ -488,17 +488,21 @@ class virtual ['class_type, 'member_type] top_pre_theory_body_class
 		   b
 		)
 
-    method virtual get_proofs : 
-      ('class_type, 'member_type) top_pre_proof_file_entry list
+      (* dependency list (aka imports) for Isar theories *)
+    method get_isar_imports = ([] : string list)
 
+(* ISAR
+ *     method virtual get_proofs : 
+ * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
+ * 
+ *)
     (* extract the proofs from a given theory
      * and give them names, if they don't have yet 
      *
-     * this should be merged with the above get_proofs at some stage
      *)
-    method extract_proofs =
+    method extract_pvs_proofs =
       let doit = function 
-    	| Proved(lemma,proof) -> 
+    	| Proved(lemma,PvsProof(proof)) -> 
 	    (match proof with
 	       | Named_proof _ -> Some proof
 	       | Anon_proof anon -> 
