@@ -18,11 +18,11 @@
  *
  * Created 22.4.99 by Bart
  *
- * Time-stamp: <Thursday 16 May 02 17:13:45 tews@ithif51>
+ * Time-stamp: <Thursday 4 July 02 18:05:25 tews@ithif51>
  *
  * top level class structure
  *
- * $Id: top_classtypes.ml,v 1.11 2002/05/22 13:42:47 tews Exp $
+ * $Id: top_classtypes.ml,v 1.12 2002/07/18 13:43:28 tews Exp $
  *
  *)
 
@@ -361,15 +361,19 @@ class type virtual ['class_type, 'member_type] top_pre_theory_body_type =
     method get_body : 
       ('class_type, 'member_type) top_pre_theory_declaration list 
 
-    method virtual get_proofs :
-      ('class_type, 'member_type) top_pre_proof_file_entry list
+      (* dependency list (aka imports) for Isar theories *)
+    method get_isar_imports : string list 
 
-    (* extract the proofs from a given theory
+(* ISAR
+ *     method virtual get_proofs :
+ * 	 ('class_type, 'member_type) top_pre_proof_file_entry list
+ *)
+
+    (* extract the pvs proofs from a given theory
      * and give them names, if they don't have yet 
      *
-     * this should be merged with the above get_proofs at some stage
      *)
-    method extract_proofs : pvs_proof list
+    method extract_pvs_proofs : pvs_proof list
 
   end
 
