@@ -18,11 +18,11 @@
  *
  * Created 22.4.99 by Bart
  *
- * Time-stamp: <Monday 24 June 02 11:56:38 tews@ithif51>
+ * Time-stamp: <Monday 15 July 02 15:11:29 tews@ithif51>
  *
  * top level type definitions
  *
- * $Id: top_variant_types.ml,v 1.26 2002/07/03 12:01:17 tews Exp $
+ * $Id: top_variant_types.ml,v 1.27 2002/07/18 13:43:28 tews Exp $
  *
  *)
 
@@ -289,6 +289,8 @@ type isa_tactic = string
 type top_theory_type =
   | Theory 
   | Datatype 
+  | IsabelleStartFile
+  | IsabelleCloseFile
 
 
 
@@ -307,6 +309,9 @@ type pvs_proof_tree  =   PTree of lisp_expr list * pvs_proof_tree list
 type pvs_proof       =   Named_proof of string * pvs_proof_tree
 		       | Anon_proof of pvs_proof_tree
 
+type proof_type =   PvsProof of pvs_proof
+		  | IsarProof		(* no proofs for isar yet *)
+
 (***********************************************************************
  ***********************************************************************
  *
@@ -534,14 +539,7 @@ and ('cl, 'mem) top_pre_expressions =
   | Map of
       ('cl, 'mem) top_pre_types * ('cl, 'mem) top_pre_expressions list
   | Expression of ('cl, 'mem) top_pre_formulas
-	  (* Sidecondition: empty 'a list raises 
-           * exception *)
-  | Comment_str of string * ('cl, 'mem) top_pre_expressions
-	       	(* the first expression gets commented *)
-  | Comment_expr of 
-      ('cl, 'mem) top_pre_expressions * 
-      ('cl, 'mem) top_pre_types * 
-      ('cl, 'mem) top_pre_expressions
+
 		(* PVS specifics *)
   | Comprehension of 
       string * ('cl, 'mem) top_pre_types * ('cl, 'mem) top_pre_formulas
@@ -663,14 +661,18 @@ and ('cl, 'mem) top_pre_theory_declaration =
   | Lemma of string * ('cl, 'mem) top_pre_formulas
   | Axiom of string * ('cl, 'mem) top_pre_formulas
   | Vardecl of string * ('cl, 'mem) top_pre_types
-  | Typevardecl of string 
+
+      (* the first argument is only used for isabelle *)
+  | Typevardecl of ('cl, 'mem) top_pre_parameter_type list * string 
+
       (* Typedecl is a bit misleading, 
        * this should only be seen as type ABBREVIATION 
+       *
+       * the first argument is only used for isabelle
        *)
   | Typedecl of
       ('cl, 'mem) top_pre_parameter_type list * string * 
       ('cl, 'mem) top_pre_types
-      (* the first argument is only used for isabelle *)
   | Enumdecl of string * string list
   | Defn of 
       string * 
@@ -711,7 +713,9 @@ and ('cl, 'mem) top_pre_theory_declaration =
   | LibImport of string * string * ('cl, 'mem) top_pre_argument_type list
   | Library of string * string 
   | Conversion of string * ('cl, 'mem) top_pre_types
-  | Proved of ('cl, 'mem) top_pre_theory_declaration * pvs_proof
+  | Proved of ('cl, 'mem) top_pre_theory_declaration * proof_type
+      (* Isar ML escape *)
+  | IsarML of string
 
 and ('cl, 'mem) top_pre_proof_file_entry =
   | Proof of
