@@ -18,11 +18,11 @@
  *
  * * Created 1.10.97 by Hendrik
  *
- * Time-stamp: <Tuesday 21 May 02 17:36:04 tews@ithif51>
+ * Time-stamp: <Thursday 11 July 02 18:56:36 tews@ithif51>
  *
  * Utility functions for variant types
  *
- * $Id: top_variant_types_util.ml,v 1.22 2002/05/22 13:42:47 tews Exp $
+ * $Id: top_variant_types_util.ml,v 1.23 2002/07/18 13:43:28 tews Exp $
  *
  *)
 
@@ -528,21 +528,6 @@ and dump_top_expression = function
       "(" ^
       (dump_top_formula f) ^
       ")"
-  | Comment_str (str, e) ->
-      "Comment_str" ^
-      str ^
-      "(" ^
-      (dump_top_expression e) ^
-      ")"
-  | Comment_expr (e1, t, e2) ->
-      "Comment_expr " ^
-      "(" ^
-      (dump_top_expression e1) ^
-      " " ^
-      (dump_top_type t) ^
-      " " ^
-      (dump_top_expression e2) ^
-      ")"
   | Comprehension (str, t, f) ->
       "Comprehention " ^
       str ^
