@@ -23,7 +23,7 @@
 ;; emacs list script for producing the CCSL grammar 
 ;; user friendly version
 ;;
-;; $Id: web.el,v 1.4 2002/05/22 13:42:48 tews Exp $
+;; $Id: web.el,v 1.5 2002/07/03 12:01:18 tews Exp $
 ;; 
 
 (setq revert-without-query '("grammar\\.txt" "tmp\\.buf" "raw\\.buf"))
@@ -366,7 +366,7 @@
 (do-repetition "methodsection")
 (do-repetition "definitionsection")
 (do-repetition "classconstructorsection")
-(new-meta "creationstart" "namedformula"
+(new-meta "theoremstart" "namedformula"
 	  "identifier COLON formula SEMICOLON")
 (do-repetition "assertionsection")
 (do-abbrev "assertionstart")
@@ -392,6 +392,7 @@
 		  "request:\n"
 		  "    identifier COLON pvstype"))
 
+;(write-region (point-min) (point-max) "tmp.buf")
 ;(save-buffer)
 
 (do-abbrev "all_quant")
